import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiAppInstallations } from "../../../structures/IApiAppInstallations";
import { installation } from "../../../structures/installation";
export * as access_tokens from "./access_tokens";
export * as suspended from "./suspended";
/**
 * List installations for the authenticated app.
 * The permissions the installation has are included under the `permissions` key.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
 *
 * @tag apps
 * @path app/installations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiAppInstallations.GetHeader;
    type Query = IApiAppInstallations.GetQuery;
    type Output = installation[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/app/installations";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => installation[];
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
/**
 * Get an installation for the authenticated app.
 * Enables an authenticated GitHub App to find an installation's information using the installation id.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
 *
 * @tag apps
 * @path app/installations/:installation_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByInstallation_id(connection: IConnection<getByInstallation_id.Headers>, installation_id: string): Promise<getByInstallation_id.Output>;
export declare namespace getByInstallation_id {
    type Headers = IApiAppInstallations.GetHeader;
    type Output = installation;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/app/installations/:installation_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (installation_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => installation;
    const simulate: (connection: IConnection<getByInstallation_id.Headers>, installation_id: string) => Output;
}
/**
 * Delete an installation for the authenticated app.
 * Uninstalls a GitHub App on a user, organization, or business account. If you prefer to temporarily suspend an app's access to your account's resources, then we recommend the "[Suspend an app installation](https://docs.github.com/rest/apps/apps#suspend-an-app-installation)" endpoint.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
 *
 * @tag apps
 * @path app/installations/:installation_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByInstallation_id(connection: IConnection<eraseByInstallation_id.Headers>, installation_id: string): Promise<void>;
export declare namespace eraseByInstallation_id {
    type Headers = IApiAppInstallations.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/app/installations/:installation_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (installation_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByInstallation_id.Headers>, installation_id: string) => void;
}
