import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiAppInstallationsSuspended } from "../../../../structures/IApiAppInstallationsSuspended";
/**
 * Suspend an app installation.
 * Suspends a GitHub App on a user, organization, or business account, which blocks the app from accessing the account's resources. When a GitHub App is suspended, the app's access to the GitHub API or webhook events is blocked for that account.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
 *
 * @tag apps
 * @path app/installations/:installation_id/suspended
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByInstallation_id(connection: IConnection<putByInstallation_id.Headers>, installation_id: string): Promise<void>;
export declare namespace putByInstallation_id {
    type Headers = IApiAppInstallationsSuspended.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/app/installations/:installation_id/suspended";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (installation_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByInstallation_id.Headers>, installation_id: string) => void;
}
/**
 * Unsuspend an app installation.
 * Removes a GitHub App installation suspension.
 *
 * You must use a [JWT](https://docs.github.com/apps/building-github-apps/authenticating-with-github-apps/#authenticating-as-a-github-app) to access this endpoint.
 *
 * @tag apps
 * @path app/installations/:installation_id/suspended
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByInstallation_id(connection: IConnection<eraseByInstallation_id.Headers>, installation_id: string): Promise<void>;
export declare namespace eraseByInstallation_id {
    type Headers = IApiAppInstallationsSuspended.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/app/installations/:installation_id/suspended";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (installation_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByInstallation_id.Headers>, installation_id: string) => void;
}
