import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiEnterprisesCopilotBillingSeats } from "../../../../../structures/IApiEnterprisesCopilotBillingSeats";
import { response } from "../../../../../structures/response";
/**
 * List all Copilot seat assignments for an enterprise.
 * > [!NOTE]
 * > This endpoint is in beta and is subject to change.
 *
 * Lists all active Copilot seats across organizations or enterprise teams for an enterprise with a Copilot Business or Copilot Enterprise subscription.
 *
 * Users with access through multiple organizations or enterprise teams will only be counted toward `total_seats` once.
 *
 * For each organization or enterprise team which grants Copilot access to a user, a seat detail object will appear in the `seats` array.
 *
 * Only enterprise owners and billing managers can view assigned Copilot seats across their child organizations or enterprise teams.
 *
 * Personal access tokens (classic) need either the `manage_billing:copilot` or `read:enterprise` scopes to use this endpoint.
 *
 * @tag copilot
 * @path enterprises/:enterprise/copilot/billing/seats
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByEnterprise(connection: IConnection<getByEnterprise.Headers>, enterprise: string, query: getByEnterprise.Query): Promise<getByEnterprise.Output>;
export declare namespace getByEnterprise {
    type Headers = IApiEnterprisesCopilotBillingSeats.GetHeader;
    type Query = IApiEnterprisesCopilotBillingSeats.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/enterprises/:enterprise/copilot/billing/seats";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (enterprise: string, query: getByEnterprise.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByEnterprise.Headers>, enterprise: string, query: getByEnterprise.Query) => Output;
}
