import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiEnterprisesCopilotUsage } from "../../../../structures/IApiEnterprisesCopilotUsage";
import { copilot_minus_usage_minus_metrics } from "../../../../structures/copilot_minus_usage_minus_metrics";
/**
 * Get a summary of Copilot usage for enterprise members.
 * > [!NOTE]
 * > This endpoint is in beta and is subject to change.
 *
 * You can use this endpoint to see a daily breakdown of aggregated usage metrics for Copilot completions and Copilot Chat in the IDE
 * for all users across organizations with access to Copilot within your enterprise, with a further breakdown of suggestions, acceptances,
 * and number of active users by editor and language for each day. See the response schema tab for detailed metrics definitions.
 *
 * The response contains metrics for up to 28 days prior. Usage metrics are processed once per day for the previous day,
 * and the response will only include data up until yesterday. In order for an end user to be counted towards these metrics,
 * they must have telemetry enabled in their IDE.
 *
 * Only owners and billing managers can view Copilot usage metrics for the enterprise.
 *
 * OAuth app tokens and personal access tokens (classic) need either the `manage_billing:copilot` or `read:enterprise` scopes to use this endpoint.
 *
 * @tag copilot
 * @path enterprises/:enterprise/copilot/usage
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByEnterprise(connection: IConnection<getByEnterprise.Headers>, enterprise: string, query: getByEnterprise.Query): Promise<getByEnterprise.Output>;
export declare namespace getByEnterprise {
    type Headers = IApiEnterprisesCopilotUsage.GetHeader;
    type Query = IApiEnterprisesCopilotUsage.GetQuery;
    type Output = copilot_minus_usage_minus_metrics[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/enterprises/:enterprise/copilot/usage";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (enterprise: string, query: getByEnterprise.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => copilot_minus_usage_minus_metrics[];
    const simulate: (connection: IConnection<getByEnterprise.Headers>, enterprise: string, query: getByEnterprise.Query) => Output;
}
