import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiEnterprisesTeamCopilotUsage } from "../../../../../structures/IApiEnterprisesTeamCopilotUsage";
import { copilot_minus_usage_minus_metrics } from "../../../../../structures/copilot_minus_usage_minus_metrics";
/**
 * Get a summary of Copilot usage for an enterprise team.
 * > [!NOTE]
 * > This endpoint is in beta and is subject to change.
 *
 * You can use this endpoint to see a daily breakdown of aggregated usage metrics for Copilot completions and Copilot Chat in the IDE
 * for users within an enterprise team, with a further breakdown of suggestions, acceptances, and number of active users by editor and language for each day.
 * See the response schema tab for detailed metrics definitions.
 *
 * The response contains metrics for up to 28 days prior. Usage metrics are processed once per day for the previous day,
 * and the response will only include data up until yesterday. In order for an end user to be counted towards these metrics,
 * they must have telemetry enabled in their IDE.
 *
 * > [!NOTE]
 * > This endpoint will only return results for a given day if the enterprise team had five or more members with active Copilot licenses, as evaluated at the end of that day.
 *
 * Owners and billing managers for the enterprise that contains the enterprise team can view Copilot usage metrics for the enterprise team.
 *
 * OAuth app tokens and personal access tokens (classic) need either the `manage_billing:copilot` or `read:enterprise` scopes to use this endpoint.
 *
 * @tag copilot
 * @path enterprises/:enterprise/team/:team_slug/copilot/usage
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByEnterpriseAndTeam_slug(connection: IConnection<getByEnterpriseAndTeam_slug.Headers>, enterprise: string, team_slug: string, query: getByEnterpriseAndTeam_slug.Query): Promise<getByEnterpriseAndTeam_slug.Output>;
export declare namespace getByEnterpriseAndTeam_slug {
    type Headers = IApiEnterprisesTeamCopilotUsage.GetHeader;
    type Query = IApiEnterprisesTeamCopilotUsage.GetQuery;
    type Output = copilot_minus_usage_minus_metrics[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/enterprises/:enterprise/team/:team_slug/copilot/usage";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (enterprise: string, team_slug: string, query: getByEnterpriseAndTeam_slug.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => copilot_minus_usage_minus_metrics[];
    const simulate: (connection: IConnection<getByEnterpriseAndTeam_slug.Headers>, enterprise: string, team_slug: string, query: getByEnterpriseAndTeam_slug.Query) => Output;
}
