import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsPermissions } from "../../../../structures/IApiOrgsActionsPermissions";
import { actions_minus_organization_minus_permissions } from "../../../../structures/actions_minus_organization_minus_permissions";
import { body } from "../../../../structures/body";
export * as repositories from "./repositories";
export * as selected_actions from "./selected_actions";
export * as workflow from "./workflow";
/**
 * Get GitHub Actions permissions for an organization.
 * Gets the GitHub Actions permissions policy for repositories and allowed actions and reusable workflows in an organization.
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsPermissions.GetHeader;
    type Output = actions_minus_organization_minus_permissions;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/permissions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_organization_minus_permissions;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Set GitHub Actions permissions for an organization.
 * Sets the GitHub Actions permissions policy for repositories and allowed actions and reusable workflows in an organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrg(connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input): Promise<void>;
export declare namespace putByOrg {
    type Headers = IApiOrgsActionsPermissions.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/permissions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input) => void;
}
