import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsPermissionsRepositories } from "../../../../../structures/IApiOrgsActionsPermissionsRepositories";
import { body } from "../../../../../structures/body";
import { response } from "../../../../../structures/response";
/**
 * List selected repositories enabled for GitHub Actions in an organization.
 * Lists the selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsPermissionsRepositories.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/permissions/repositories";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Set selected repositories enabled for GitHub Actions in an organization.
 * Replaces the list of selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrg(connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input): Promise<void>;
export declare namespace putByOrg {
    type Headers = IApiOrgsActionsPermissionsRepositories.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/permissions/repositories";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input) => void;
}
/**
 * Enable a selected repository for GitHub Actions in an organization.
 * Adds a repository to the list of selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndRepository_id(connection: IConnection<putByOrgAndRepository_id.Headers>, org: string, repository_id: string): Promise<void>;
export declare namespace putByOrgAndRepository_id {
    type Headers = IApiOrgsActionsPermissionsRepositories.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/permissions/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, repository_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndRepository_id.Headers>, org: string, repository_id: string) => void;
}
/**
 * Disable a selected repository for GitHub Actions in an organization.
 * Removes a repository from the list of selected repositories that are enabled for GitHub Actions in an organization. To use this endpoint, the organization permission policy for `enabled_repositories` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndRepository_id(connection: IConnection<eraseByOrgAndRepository_id.Headers>, org: string, repository_id: string): Promise<void>;
export declare namespace eraseByOrgAndRepository_id {
    type Headers = IApiOrgsActionsPermissionsRepositories.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/permissions/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, repository_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndRepository_id.Headers>, org: string, repository_id: string) => void;
}
