import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsPermissionsSelectedActions } from "../../../../../structures/IApiOrgsActionsPermissionsSelectedActions";
import { selected_minus_actions } from "../../../../../structures/selected_minus_actions";
/**
 * Get allowed actions and reusable workflows for an organization.
 * Gets the selected actions and reusable workflows that are allowed in an organization. To use this endpoint, the organization permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/selected-actions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsPermissionsSelectedActions.GetHeader;
    type Output = selected_minus_actions;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/permissions/selected-actions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => selected_minus_actions;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Set allowed actions and reusable workflows for an organization.
 * Sets the actions and reusable workflows that are allowed in an organization. To use this endpoint, the organization permission policy for `allowed_actions` must be configured to `selected`. For more information, see "[Set GitHub Actions permissions for an organization](#set-github-actions-permissions-for-an-organization)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/permissions/selected-actions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrg(connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input): Promise<void>;
export declare namespace putByOrg {
    type Headers = IApiOrgsActionsPermissionsSelectedActions.PutHeader;
    type Input = selected_minus_actions;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/permissions/selected-actions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrg.Headers>, org: string, body: putByOrg.Input) => void;
}
