import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsRunners } from "../../../../structures/IApiOrgsActionsRunners";
import { response } from "../../../../structures/response";
import { runner } from "../../../../structures/runner";
export * as downloads from "./downloads";
export * as generate_jitconfig from "./generate_jitconfig";
export * as registration_token from "./registration_token";
export * as remove_token from "./remove_token";
export * as labels from "./labels";
/**
 * List self-hosted runners for an organization.
 * Lists all self-hosted runners configured in an organization.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/runners
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsRunners.GetHeader;
    type Query = IApiOrgsActionsRunners.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/runners";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Get a self-hosted runner for an organization.
 * Gets a specific self-hosted runner configured in an organization.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndRunner_id(connection: IConnection<getByOrgAndRunner_id.Headers>, org: string, runner_id: string): Promise<getByOrgAndRunner_id.Output>;
export declare namespace getByOrgAndRunner_id {
    type Headers = IApiOrgsActionsRunners.GetHeader;
    type Output = runner;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/runners/:runner_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => runner;
    const simulate: (connection: IConnection<getByOrgAndRunner_id.Headers>, org: string, runner_id: string) => Output;
}
/**
 * Delete a self-hosted runner from an organization.
 * Forces the removal of a self-hosted runner from an organization. You can use this endpoint to completely remove the runner when the machine you were using no longer exists.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndRunner_id(connection: IConnection<eraseByOrgAndRunner_id.Headers>, org: string, runner_id: string): Promise<void>;
export declare namespace eraseByOrgAndRunner_id {
    type Headers = IApiOrgsActionsRunners.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/runners/:runner_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndRunner_id.Headers>, org: string, runner_id: string) => void;
}
