import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsRunnersLabels } from "../../../../../structures/IApiOrgsActionsRunnersLabels";
import { body } from "../../../../../structures/body";
import { response } from "../../../../../structures/response";
/**
 * List labels for a self-hosted runner for an organization.
 * Lists all labels for a self-hosted runner configured in an organization.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndRunner_id(connection: IConnection<getByOrgAndRunner_id.Headers>, org: string, runner_id: string): Promise<getByOrgAndRunner_id.Output>;
export declare namespace getByOrgAndRunner_id {
    type Headers = IApiOrgsActionsRunnersLabels.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/runners/:runner_id/labels";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrgAndRunner_id.Headers>, org: string, runner_id: string) => Output;
}
/**
 * Add custom labels to a self-hosted runner for an organization.
 * Adds custom labels to a self-hosted runner configured in an organization.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrgAndRunner_id(connection: IConnection<postByOrgAndRunner_id.Headers>, org: string, runner_id: string, body: postByOrgAndRunner_id.Input): Promise<postByOrgAndRunner_id.Output>;
export declare namespace postByOrgAndRunner_id {
    type Headers = IApiOrgsActionsRunnersLabels.PostHeader;
    type Input = body;
    type Output = response;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/actions/runners/:runner_id/labels";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<postByOrgAndRunner_id.Headers>, org: string, runner_id: string, body: postByOrgAndRunner_id.Input) => Output;
}
/**
 * Set custom labels for a self-hosted runner for an organization.
 * Remove all previous custom labels and set the new custom labels for a specific
 * self-hosted runner configured in an organization.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndRunner_id(connection: IConnection<putByOrgAndRunner_id.Headers>, org: string, runner_id: string, body: putByOrgAndRunner_id.Input): Promise<putByOrgAndRunner_id.Output>;
export declare namespace putByOrgAndRunner_id {
    type Headers = IApiOrgsActionsRunnersLabels.PutHeader;
    type Input = body;
    type Output = response;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/runners/:runner_id/labels";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<putByOrgAndRunner_id.Headers>, org: string, runner_id: string, body: putByOrgAndRunner_id.Input) => Output;
}
/**
 * Remove all custom labels from a self-hosted runner for an organization.
 * Remove all custom labels from a self-hosted runner configured in an
 * organization. Returns the remaining read-only labels from the runner.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndRunner_id(connection: IConnection<eraseByOrgAndRunner_id.Headers>, org: string, runner_id: string): Promise<eraseByOrgAndRunner_id.Output>;
export declare namespace eraseByOrgAndRunner_id {
    type Headers = IApiOrgsActionsRunnersLabels.DeleteHeader;
    type Output = response;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/runners/:runner_id/labels";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<eraseByOrgAndRunner_id.Headers>, org: string, runner_id: string) => Output;
}
/**
 * Remove a custom label from a self-hosted runner for an organization.
 * Remove a custom label from a self-hosted runner configured
 * in an organization. Returns the remaining labels from the runner.
 *
 * This endpoint returns a `404 Not Found` status if the custom label is not
 * present on the runner.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/:runner_id/labels/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndRunner_idAndName(connection: IConnection<eraseByOrgAndRunner_idAndName.Headers>, org: string, runner_id: string, name: string): Promise<eraseByOrgAndRunner_idAndName.Output>;
export declare namespace eraseByOrgAndRunner_idAndName {
    type Headers = IApiOrgsActionsRunnersLabels.DeleteHeader;
    type Output = response;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/runners/:runner_id/labels/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, runner_id: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<eraseByOrgAndRunner_idAndName.Headers>, org: string, runner_id: string, name: string) => Output;
}
