import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsRunnersRemoveToken } from "../../../../../structures/IApiOrgsActionsRunnersRemoveToken";
import { authentication_minus_token } from "../../../../../structures/authentication_minus_token";
/**
 * Create a remove token for an organization.
 * Returns a token that you can pass to the `config` script to remove a self-hosted runner from an organization. The token expires after one hour.
 *
 * For example, you can replace `TOKEN` in the following example with the registration token provided by this endpoint to remove your self-hosted runner from an organization:
 *
 * ```
 * ./config.sh remove --token TOKEN
 * ```
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/runners/remove-token
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string): Promise<postByOrg.Output>;
export declare namespace postByOrg {
    type Headers = IApiOrgsActionsRunnersRemoveToken.PostHeader;
    type Output = authentication_minus_token;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/actions/runners/remove-token";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => authentication_minus_token;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string) => Output;
}
