import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsActionsSecrets } from "../../../../structures/IApiOrgsActionsSecrets";
import { body } from "../../../../structures/body";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { organization_minus_actions_minus_secret } from "../../../../structures/organization_minus_actions_minus_secret";
import { response } from "../../../../structures/response";
export * as public_key from "./public_key";
export * as repositories from "./repositories";
/**
 * List organization secrets.
 * Lists all secrets available in an organization without revealing their
 * encrypted values.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/secrets
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsActionsSecrets.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/secrets";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Get an organization secret.
 * Gets a single organization secret without revealing its encrypted value.
 *
 * The authenticated user must have collaborator access to a repository to create, update, or read secrets
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndSecret_name(connection: IConnection<getByOrgAndSecret_name.Headers>, org: string, secret_name: string): Promise<getByOrgAndSecret_name.Output>;
export declare namespace getByOrgAndSecret_name {
    type Headers = IApiOrgsActionsSecrets.GetHeader;
    type Output = organization_minus_actions_minus_secret;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => organization_minus_actions_minus_secret;
    const simulate: (connection: IConnection<getByOrgAndSecret_name.Headers>, org: string, secret_name: string) => Output;
}
/**
 * Create or update an organization secret.
 * Creates or updates an organization secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). For more information, see "[Encrypting secrets for the REST API](https://docs.github.com/rest/guides/encrypting-secrets-for-the-rest-api)."
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndSecret_name(connection: IConnection<putByOrgAndSecret_name.Headers>, org: string, secret_name: string, body: putByOrgAndSecret_name.Input): Promise<putByOrgAndSecret_name.Output>;
export declare namespace putByOrgAndSecret_name {
    type Headers = IApiOrgsActionsSecrets.PutHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/secrets/:secret_name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<putByOrgAndSecret_name.Headers>, org: string, secret_name: string, body: putByOrgAndSecret_name.Input) => Output;
}
/**
 * Delete an organization secret.
 * Deletes a secret in an organization using the secret name.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth tokens and personal access tokens (classic) need the`admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndSecret_name(connection: IConnection<eraseByOrgAndSecret_name.Headers>, org: string, secret_name: string): Promise<void>;
export declare namespace eraseByOrgAndSecret_name {
    type Headers = IApiOrgsActionsSecrets.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndSecret_name.Headers>, org: string, secret_name: string) => void;
}
