import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiOrgsActionsVariablesRepositories } from "../../../../../structures/IApiOrgsActionsVariablesRepositories";
import { body } from "../../../../../structures/body";
import { response } from "../../../../../structures/response";
/**
 * List selected repositories for an organization variable.
 * Lists all repositories that can access an organization variable
 * that is available to selected repositories.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndName(connection: IConnection<getByOrgAndName.Headers>, org: string, name: string): Promise<getByOrgAndName.Output>;
export declare namespace getByOrgAndName {
    type Headers = IApiOrgsActionsVariablesRepositories.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/actions/variables/:name/repositories";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrgAndName.Headers>, org: string, name: string) => Output;
}
/**
 * Set selected repositories for an organization variable.
 * Replaces all repositories for an organization variable that is available
 * to selected repositories. Organization variables that are available to selected
 * repositories have their `visibility` field set to `selected`.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndName(connection: IConnection<putByOrgAndName.Headers>, org: string, name: string, body: putByOrgAndName.Input): Promise<void>;
export declare namespace putByOrgAndName {
    type Headers = IApiOrgsActionsVariablesRepositories.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/variables/:name/repositories";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndName.Headers>, org: string, name: string, body: putByOrgAndName.Input) => void;
}
/**
 * Add selected repository to an organization variable.
 * Adds a repository to an organization variable that is available to selected repositories.
 * Organization variables that are available to selected repositories have their `visibility` field set to `selected`.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndNameAndRepository_id(connection: IConnection<putByOrgAndNameAndRepository_id.Headers>, org: string, name: string, repository_id: number & tags.Type<"int32">): Promise<void>;
export declare namespace putByOrgAndNameAndRepository_id {
    type Headers = IApiOrgsActionsVariablesRepositories.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/actions/variables/:name/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string, repository_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndNameAndRepository_id.Headers>, org: string, name: string, repository_id: number & tags.Type<"int32">) => void;
}
/**
 * Remove selected repository from an organization variable.
 * Removes a repository from an organization variable that is
 * available to selected repositories. Organization variables that are available to
 * selected repositories have their `visibility` field set to `selected`.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read variables.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint. If the repository is private, the `repo` scope is also required.
 *
 * @tag actions
 * @path orgs/:org/actions/variables/:name/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndNameAndRepository_id(connection: IConnection<eraseByOrgAndNameAndRepository_id.Headers>, org: string, name: string, repository_id: number & tags.Type<"int32">): Promise<void>;
export declare namespace eraseByOrgAndNameAndRepository_id {
    type Headers = IApiOrgsActionsVariablesRepositories.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/actions/variables/:name/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, name: string, repository_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndNameAndRepository_id.Headers>, org: string, name: string, repository_id: number & tags.Type<"int32">) => void;
}
