import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsAttestations } from "../../../structures/IApiOrgsAttestations";
import { response } from "../../../structures/response";
/**
 * List attestations.
 * List a collection of artifact attestations with a given subject digest that are associated with repositories owned by an organization.
 *
 * The collection of attestations returned by this endpoint is filtered according to the authenticated user's permissions; if the authenticated user cannot read a repository, the attestations associated with that repository will not be included in the response. In addition, when using a fine-grained access token the `attestations:read` permission is required.
 *
 * **Please note:** in order to offer meaningful security benefits, an attestation's signature and timestamps **must** be cryptographically verified, and the identity of the attestation signer **must** be validated. Attestations can be verified using the [GitHub CLI `attestation verify` command](https://cli.github.com/manual/gh_attestation_verify). For more information, see [our guide on how to use artifact attestations to establish a build's provenance](https://docs.github.com/actions/security-guides/using-artifact-attestations-to-establish-provenance-for-builds).
 *
 * @param subject_digest The parameter should be set to the attestation's subject's SHA256 digest, in the form `sha256:HEX_DIGEST`.
 * @tag orgs
 * @path orgs/:org/attestations/:subject_digest
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndSubject_digest(connection: IConnection<getByOrgAndSubject_digest.Headers>, org: string, subject_digest: string): Promise<getByOrgAndSubject_digest.Output>;
export declare namespace getByOrgAndSubject_digest {
    type Headers = IApiOrgsAttestations.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/attestations/:subject_digest";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, subject_digest: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrgAndSubject_digest.Headers>, org: string, subject_digest: string) => Output;
}
