import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsCodeSecurityConfigurationsDefaults } from "../../../../../structures/IApiOrgsCodeSecurityConfigurationsDefaults";
import { body } from "../../../../../structures/body";
import { code_minus_security_minus_default_minus_configurations } from "../../../../../structures/code_minus_security_minus_default_minus_configurations";
import { response } from "../../../../../structures/response";
/**
 * Get default code security configurations.
 * Lists the default code security configurations for an organization.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations/defaults
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsCodeSecurityConfigurationsDefaults.GetHeader;
    type Output = code_minus_security_minus_default_minus_configurations;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/code-security/configurations/defaults";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_security_minus_default_minus_configurations;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Set a code security configuration as a default for an organization.
 * Sets a code security configuration as a default to be applied to new repositories in your organization.
 *
 * This configuration will be applied to the matching repository type (all, none, public, private and internal) by default when they are created.
 *
 * The authenticated user must be an administrator or security manager for the organization to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:org` scope to use this endpoint.
 *
 * @tag code-security
 * @path orgs/:org/code-security/configurations/:configuration_id/defaults
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndConfiguration_id(connection: IConnection<putByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string, body: putByOrgAndConfiguration_id.Input): Promise<putByOrgAndConfiguration_id.Output>;
export declare namespace putByOrgAndConfiguration_id {
    type Headers = IApiOrgsCodeSecurityConfigurationsDefaults.PutHeader;
    type Input = body;
    type Output = response;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/code-security/configurations/:configuration_id/defaults";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, configuration_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<putByOrgAndConfiguration_id.Headers>, org: string, configuration_id: string, body: putByOrgAndConfiguration_id.Input) => Output;
}
