import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsCopilotBilling } from "../../../../structures/IApiOrgsCopilotBilling";
import { copilot_minus_organization_minus_details } from "../../../../structures/copilot_minus_organization_minus_details";
export * as seats from "./seats";
export * as selected_teams from "./selected_teams";
export * as selected_users from "./selected_users";
/**
 * Get Copilot seat information and settings for an organization.
 * > [!NOTE]
 * > This endpoint is in beta and is subject to change.
 *
 * Gets information about an organization's Copilot subscription, including seat breakdown
 * and feature policies. To configure these settings, go to your organization's settings on GitHub.com.
 * For more information, see "[Managing policies for Copilot in your organization](https://docs.github.com/copilot/managing-copilot/managing-policies-for-copilot-business-in-your-organization)".
 *
 * Only organization owners can view details about the organization's Copilot Business or Copilot Enterprise subscription.
 *
 * OAuth app tokens and personal access tokens (classic) need either the `manage_billing:copilot` or `read:org` scopes to use this endpoint.
 *
 * @tag copilot
 * @path orgs/:org/copilot/billing
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsCopilotBilling.GetHeader;
    type Output = copilot_minus_organization_minus_details;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/copilot/billing";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => copilot_minus_organization_minus_details;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
