import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsCopilotUsage } from "../../../../structures/IApiOrgsCopilotUsage";
import { copilot_minus_usage_minus_metrics } from "../../../../structures/copilot_minus_usage_minus_metrics";
/**
 * Get a summary of Copilot usage for organization members.
 * > [!NOTE]
 * > This endpoint is in beta and is subject to change.
 *
 * You can use this endpoint to see a daily breakdown of aggregated usage metrics for Copilot completions and Copilot Chat in the IDE
 * across an organization, with a further breakdown of suggestions, acceptances, and number of active users by editor and language for each day.
 * See the response schema tab for detailed metrics definitions.
 *
 * The response contains metrics for up to 28 days prior. Usage metrics are processed once per day for the previous day,
 * and the response will only include data up until yesterday. In order for an end user to be counted towards these metrics,
 * they must have telemetry enabled in their IDE.
 *
 * Organization owners, and owners and billing managers of the parent enterprise, can view Copilot usage metrics.
 *
 * OAuth app tokens and personal access tokens (classic) need either the `manage_billing:copilot`, `read:org`, or `read:enterprise` scopes to use this endpoint.
 *
 * @tag copilot
 * @path orgs/:org/copilot/usage
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsCopilotUsage.GetHeader;
    type Query = IApiOrgsCopilotUsage.GetQuery;
    type Output = copilot_minus_usage_minus_metrics[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/copilot/usage";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => copilot_minus_usage_minus_metrics[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
