import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsMigrations } from "../../../structures/IApiOrgsMigrations";
import { body } from "../../../structures/body";
import { migration } from "../../../structures/migration";
export * as archive from "./archive";
export * as repos from "./repos";
export * as repositories from "./repositories";
/**
 * List organization migrations.
 * Lists the most recent migrations, including both exports (which can be started through the REST API) and imports (which cannot be started using the REST API).
 *
 * A list of `repositories` is only returned for export migrations.
 *
 * @tag migrations
 * @path orgs/:org/migrations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsMigrations.GetHeader;
    type Query = IApiOrgsMigrations.GetQuery;
    type Output = migration[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/migrations";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => migration[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Start an organization migration.
 * Initiates the generation of a migration archive.
 *
 * @tag migrations
 * @path orgs/:org/migrations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<postByOrg.Output>;
export declare namespace postByOrg {
    type Headers = IApiOrgsMigrations.PostHeader;
    type Input = body;
    type Output = migration;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/migrations";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => migration;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => Output;
}
/**
 * Get an organization migration status.
 * Fetches the status of a migration.
 *
 * The `state` of a migration can be one of the following values:
 *
 * *   `pending`, which means the migration hasn't started yet.
 * *   `exporting`, which means the migration is in progress.
 * *   `exported`, which means the migration finished successfully.
 * *   `failed`, which means the migration failed.
 *
 * @tag migrations
 * @path orgs/:org/migrations/:migration_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndMigration_id(connection: IConnection<getByOrgAndMigration_id.Headers>, org: string, migration_id: string, query: getByOrgAndMigration_id.Query): Promise<getByOrgAndMigration_id.Output>;
export declare namespace getByOrgAndMigration_id {
    type Headers = IApiOrgsMigrations.GetHeader;
    type Query = IApiOrgsMigrations.GetQuery;
    type Output = migration;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/migrations/:migration_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, migration_id: string, query: getByOrgAndMigration_id.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => migration;
    const simulate: (connection: IConnection<getByOrgAndMigration_id.Headers>, org: string, migration_id: string, query: getByOrgAndMigration_id.Query) => Output;
}
