import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsOrganizationRoles } from "../../../structures/IApiOrgsOrganizationRoles";
import { organization_minus_role } from "../../../structures/organization_minus_role";
import { response } from "../../../structures/response";
export * as teams from "./teams";
export * as users from "./users";
/**
 * Get all organization roles for an organization.
 * Lists the organization roles available in this organization. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * To use this endpoint, the authenticated user must be one of:
 *
 * - An administrator for the organization.
 * - A user, or a user on a team, with the fine-grained permissions of `read_organization_custom_org_role` in the organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsOrganizationRoles.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/organization-roles";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Get an organization role.
 * Gets an organization role that is available to this organization. For more information on organization roles, see "[Using organization roles](https://docs.github.com/organizations/managing-peoples-access-to-your-organization-with-roles/using-organization-roles)."
 *
 * To use this endpoint, the authenticated user must be one of:
 *
 * - An administrator for the organization.
 * - A user, or a user on a team, with the fine-grained permissions of `read_organization_custom_org_role` in the organization.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:org` scope to use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/organization-roles/:role_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndRole_id(connection: IConnection<getByOrgAndRole_id.Headers>, org: string, role_id: string): Promise<getByOrgAndRole_id.Output>;
export declare namespace getByOrgAndRole_id {
    type Headers = IApiOrgsOrganizationRoles.GetHeader;
    type Output = organization_minus_role;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/organization-roles/:role_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, role_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => organization_minus_role;
    const simulate: (connection: IConnection<getByOrgAndRole_id.Headers>, org: string, role_id: string) => Output;
}
