import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsOutsideCollaborators } from "../../../structures/IApiOrgsOutsideCollaborators";
import { body } from "../../../structures/body";
import { simple_minus_user } from "../../../structures/simple_minus_user";
/**
 * List outside collaborators for an organization.
 * List all users who are outside collaborators of an organization.
 *
 * @tag orgs
 * @path orgs/:org/outside_collaborators
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsOutsideCollaborators.GetHeader;
    type Query = IApiOrgsOutsideCollaborators.GetQuery;
    type Output = simple_minus_user[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/outside_collaborators";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => simple_minus_user[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Convert an organization member to outside collaborator.
 * When an organization member is converted to an outside collaborator, they'll only have access to the repositories that their current team membership allows. The user will no longer be a member of the organization. For more information, see "[Converting an organization member to an outside collaborator](https://docs.github.com/articles/converting-an-organization-member-to-an-outside-collaborator/)". Converting an organization member to an outside collaborator may be restricted by enterprise administrators. For more information, see "[Enforcing repository management policies in your enterprise](https://docs.github.com/admin/policies/enforcing-policies-for-your-enterprise/enforcing-repository-management-policies-in-your-enterprise#enforcing-a-policy-for-inviting-outside-collaborators-to-repositories)."
 *
 * @tag orgs
 * @path orgs/:org/outside_collaborators/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOrgAndUsername(connection: IConnection<putByOrgAndUsername.Headers>, org: string, username: string, body: putByOrgAndUsername.Input): Promise<void>;
export declare namespace putByOrgAndUsername {
    type Headers = IApiOrgsOutsideCollaborators.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/orgs/:org/outside_collaborators/:username";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOrgAndUsername.Headers>, org: string, username: string, body: putByOrgAndUsername.Input) => void;
}
/**
 * Remove outside collaborator from an organization.
 * Removing a user from this list will remove them from all the organization's repositories.
 *
 * @tag orgs
 * @path orgs/:org/outside_collaborators/:username
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndUsername(connection: IConnection<eraseByOrgAndUsername.Headers>, org: string, username: string): Promise<void>;
export declare namespace eraseByOrgAndUsername {
    type Headers = IApiOrgsOutsideCollaborators.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/outside_collaborators/:username";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, username: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndUsername.Headers>, org: string, username: string) => void;
}
