import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiOrgsPersonalAccessTokenRequests } from "../../../structures/IApiOrgsPersonalAccessTokenRequests";
import { body } from "../../../structures/body";
import { organization_minus_programmatic_minus_access_minus_grant_minus_request } from "../../../structures/organization_minus_programmatic_minus_access_minus_grant_minus_request";
export * as repositories from "./repositories";
/**
 * List requests to access organization resources with fine-grained personal access tokens.
 * Lists requests from organization members to access organization resources with a fine-grained personal access token.
 *
 * Only GitHub Apps can use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/personal-access-token-requests
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsPersonalAccessTokenRequests.GetHeader;
    type Output = organization_minus_programmatic_minus_access_minus_grant_minus_request[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/personal-access-token-requests";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => organization_minus_programmatic_minus_access_minus_grant_minus_request[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Review requests to access organization resources with fine-grained personal access tokens.
 * Approves or denies multiple pending requests to access organization resources via a fine-grained personal access token.
 *
 * Only GitHub Apps can use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/personal-access-token-requests
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<void>;
export declare namespace postByOrg {
    type Headers = IApiOrgsPersonalAccessTokenRequests.PostHeader;
    type Input = body;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/personal-access-token-requests";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => void;
}
/**
 * Review a request to access organization resources with a fine-grained personal access token.
 * Approves or denies a pending request to access organization resources via a fine-grained personal access token.
 *
 * Only GitHub Apps can use this endpoint.
 *
 * @param pat_request_id Unique identifier of the request for access via fine-grained personal access token.
 * @tag orgs
 * @path orgs/:org/personal-access-token-requests/:pat_request_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrgAndPat_request_id(connection: IConnection<postByOrgAndPat_request_id.Headers>, org: string, pat_request_id: number & tags.Type<"int32">, body: postByOrgAndPat_request_id.Input): Promise<void>;
export declare namespace postByOrgAndPat_request_id {
    type Headers = IApiOrgsPersonalAccessTokenRequests.PostHeader;
    type Input = body;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/personal-access-token-requests/:pat_request_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, pat_request_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByOrgAndPat_request_id.Headers>, org: string, pat_request_id: number & tags.Type<"int32">, body: postByOrgAndPat_request_id.Input) => void;
}
