import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsPersonalAccessTokens } from "../../../structures/IApiOrgsPersonalAccessTokens";
import { body } from "../../../structures/body";
import { organization_minus_programmatic_minus_access_minus_grant } from "../../../structures/organization_minus_programmatic_minus_access_minus_grant";
export * as repositories from "./repositories";
/**
 * List fine-grained personal access tokens with access to organization resources.
 * Lists approved fine-grained personal access tokens owned by organization members that can access organization resources.
 *
 * Only GitHub Apps can use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/personal-access-tokens
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsPersonalAccessTokens.GetHeader;
    type Output = organization_minus_programmatic_minus_access_minus_grant[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/personal-access-tokens";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => organization_minus_programmatic_minus_access_minus_grant[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Update the access to organization resources via fine-grained personal access tokens.
 * Updates the access organization members have to organization resources via fine-grained personal access tokens. Limited to revoking a token's existing access.
 *
 * Only GitHub Apps can use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/personal-access-tokens
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<void>;
export declare namespace postByOrg {
    type Headers = IApiOrgsPersonalAccessTokens.PostHeader;
    type Input = body;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/personal-access-tokens";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => void;
}
/**
 * Update the access a fine-grained personal access token has to organization resources.
 * Updates the access an organization member has to organization resources via a fine-grained personal access token. Limited to revoking the token's existing access. Limited to revoking a token's existing access.
 *
 * Only GitHub Apps can use this endpoint.
 *
 * @tag orgs
 * @path orgs/:org/personal-access-tokens/:pat_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrgAndPat_id(connection: IConnection<postByOrgAndPat_id.Headers>, org: string, pat_id: string, body: postByOrgAndPat_id.Input): Promise<void>;
export declare namespace postByOrgAndPat_id {
    type Headers = IApiOrgsPersonalAccessTokens.PostHeader;
    type Input = body;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/personal-access-tokens/:pat_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, pat_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByOrgAndPat_id.Headers>, org: string, pat_id: string, body: postByOrgAndPat_id.Input) => void;
}
