import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsProjects } from "../../../structures/IApiOrgsProjects";
import { body } from "../../../structures/body";
import { project } from "../../../structures/project";
/**
 * List organization projects.
 * Lists the projects in an organization. Returns a `404 Not Found` status if projects are disabled in the organization. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
 *
 * @tag projects
 * @path orgs/:org/projects
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiOrgsProjects.GetHeader;
    type Query = IApiOrgsProjects.GetQuery;
    type Output = project[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/projects";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, query: getByOrg.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => project[];
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string, query: getByOrg.Query) => Output;
}
/**
 * Create an organization project.
 * Creates an organization project board. Returns a `410 Gone` status if projects are disabled in the organization or if the organization does not have existing classic projects. If you do not have sufficient privileges to perform this action, a `401 Unauthorized` or `410 Gone` status is returned.
 *
 * @tag projects
 * @path orgs/:org/projects
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrg(connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input): Promise<postByOrg.Output>;
export declare namespace postByOrg {
    type Headers = IApiOrgsProjects.PostHeader;
    type Input = body;
    type Output = project;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/projects";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => project;
    const simulate: (connection: IConnection<postByOrg.Headers>, org: string, body: postByOrg.Input) => Output;
}
