import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsTeamsDiscussionsComments } from "../../../../../structures/IApiOrgsTeamsDiscussionsComments";
import { body } from "../../../../../structures/body";
import { team_minus_discussion_minus_comment } from "../../../../../structures/team_minus_discussion_minus_comment";
export * as reactions from "./reactions";
/**
 * List discussion comments.
 * List all comments on a team discussion.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slugAndDiscussion_number(connection: IConnection<getByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string): Promise<getByOrgAndTeam_slugAndDiscussion_number.Output>;
export declare namespace getByOrgAndTeam_slugAndDiscussion_number {
    type Headers = IApiOrgsTeamsDiscussionsComments.GetHeader;
    type Output = team_minus_discussion_minus_comment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment[];
    const simulate: (connection: IConnection<getByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string) => Output;
}
/**
 * Create a discussion comment.
 * Creates a new comment on a team discussion.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrgAndTeam_slugAndDiscussion_number(connection: IConnection<postByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string, body: postByOrgAndTeam_slugAndDiscussion_number.Input): Promise<postByOrgAndTeam_slugAndDiscussion_number.Output>;
export declare namespace postByOrgAndTeam_slugAndDiscussion_number {
    type Headers = IApiOrgsTeamsDiscussionsComments.PostHeader;
    type Input = body;
    type Output = team_minus_discussion_minus_comment;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment;
    const simulate: (connection: IConnection<postByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string, body: postByOrgAndTeam_slugAndDiscussion_number.Input) => Output;
}
/**
 * Get a discussion comment.
 * Get a specific comment on a team discussion.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments/{comment_number}`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slugAndDiscussion_numberAndComment_number(connection: IConnection<getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string): Promise<getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Output>;
export declare namespace getByOrgAndTeam_slugAndDiscussion_numberAndComment_number {
    type Headers = IApiOrgsTeamsDiscussionsComments.GetHeader;
    type Output = team_minus_discussion_minus_comment;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment;
    const simulate: (connection: IConnection<getByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string) => Output;
}
/**
 * Update a discussion comment.
 * Edits the body text of a discussion comment.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `PATCH /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments/{comment_number}`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number(connection: IConnection<patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, body: patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Input): Promise<patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Output>;
export declare namespace patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number {
    type Headers = IApiOrgsTeamsDiscussionsComments.PatchHeader;
    type Input = body;
    type Output = team_minus_discussion_minus_comment;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment;
    const simulate: (connection: IConnection<patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string, body: patchByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Input) => Output;
}
/**
 * Delete a discussion comment.
 * Deletes a comment on a team discussion.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}/comments/{comment_number}`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_number(connection: IConnection<eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_number {
    type Headers = IApiOrgsTeamsDiscussionsComments.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number/comments/:comment_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slugAndDiscussion_numberAndComment_number.Headers>, org: string, team_slug: string, discussion_number: string, comment_number: string) => void;
}
