import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiOrgsTeamsDiscussions } from "../../../../structures/IApiOrgsTeamsDiscussions";
import { body } from "../../../../structures/body";
import { team_minus_discussion } from "../../../../structures/team_minus_discussion";
export * as comments from "./comments";
export * as reactions from "./reactions";
/**
 * List discussions.
 * List all discussions on a team's page.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slug(connection: IConnection<getByOrgAndTeam_slug.Headers>, org: string, team_slug: string, query: getByOrgAndTeam_slug.Query): Promise<getByOrgAndTeam_slug.Output>;
export declare namespace getByOrgAndTeam_slug {
    type Headers = IApiOrgsTeamsDiscussions.GetHeader;
    type Query = IApiOrgsTeamsDiscussions.GetQuery;
    type Output = team_minus_discussion[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/discussions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, query: getByOrgAndTeam_slug.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion[];
    const simulate: (connection: IConnection<getByOrgAndTeam_slug.Headers>, org: string, team_slug: string, query: getByOrgAndTeam_slug.Query) => Output;
}
/**
 * Create a discussion.
 * Creates a new discussion post on a team's page.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `POST /organizations/{org_id}/team/{team_id}/discussions`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOrgAndTeam_slug(connection: IConnection<postByOrgAndTeam_slug.Headers>, org: string, team_slug: string, body: postByOrgAndTeam_slug.Input): Promise<postByOrgAndTeam_slug.Output>;
export declare namespace postByOrgAndTeam_slug {
    type Headers = IApiOrgsTeamsDiscussions.PostHeader;
    type Input = body;
    type Output = team_minus_discussion;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/orgs/:org/teams/:team_slug/discussions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion;
    const simulate: (connection: IConnection<postByOrgAndTeam_slug.Headers>, org: string, team_slug: string, body: postByOrgAndTeam_slug.Input) => Output;
}
/**
 * Get a discussion.
 * Get a specific discussion on a team's page.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `GET /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrgAndTeam_slugAndDiscussion_number(connection: IConnection<getByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string): Promise<getByOrgAndTeam_slugAndDiscussion_number.Output>;
export declare namespace getByOrgAndTeam_slugAndDiscussion_number {
    type Headers = IApiOrgsTeamsDiscussions.GetHeader;
    type Output = team_minus_discussion;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion;
    const simulate: (connection: IConnection<getByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string) => Output;
}
/**
 * Update a discussion.
 * Edits the title and body text of a discussion post. Only the parameters you provide are updated.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `PATCH /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrgAndTeam_slugAndDiscussion_number(connection: IConnection<patchByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string, body: patchByOrgAndTeam_slugAndDiscussion_number.Input): Promise<patchByOrgAndTeam_slugAndDiscussion_number.Output>;
export declare namespace patchByOrgAndTeam_slugAndDiscussion_number {
    type Headers = IApiOrgsTeamsDiscussions.PatchHeader;
    type Input = body;
    type Output = team_minus_discussion;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion;
    const simulate: (connection: IConnection<patchByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string, body: patchByOrgAndTeam_slugAndDiscussion_number.Input) => Output;
}
/**
 * Delete a discussion from a team's page.
 *
 * > [!NOTE]
 * > You can also specify a team by `org_id` and `team_id` using the route `DELETE /organizations/{org_id}/team/{team_id}/discussions/{discussion_number}`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @path orgs/:org/teams/:team_slug/discussions/:discussion_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOrgAndTeam_slugAndDiscussion_number(connection: IConnection<eraseByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string): Promise<void>;
export declare namespace eraseByOrgAndTeam_slugAndDiscussion_number {
    type Headers = IApiOrgsTeamsDiscussions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/orgs/:org/teams/:team_slug/discussions/:discussion_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string, team_slug: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOrgAndTeam_slugAndDiscussion_number.Headers>, org: string, team_slug: string, discussion_number: string) => void;
}
