import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsPermissionsAccess } from "../../../../../structures/IApiReposActionsPermissionsAccess";
import { actions_minus_workflow_minus_access_minus_to_minus_repository } from "../../../../../structures/actions_minus_workflow_minus_access_minus_to_minus_repository";
/**
 * Get the level of access for workflows outside of the repository.
 * Gets the level of access that workflows outside of the repository have to actions and reusable workflows in the repository.
 * This endpoint only applies to private repositories.
 * For more information, see "[Allowing access to components in a private repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#allowing-access-to-components-in-a-private-repository)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/permissions/access
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsPermissionsAccess.GetHeader;
    type Output = actions_minus_workflow_minus_access_minus_to_minus_repository;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/permissions/access";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_workflow_minus_access_minus_to_minus_repository;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Set the level of access for workflows outside of the repository.
 * Sets the level of access that workflows outside of the repository have to actions and reusable workflows in the repository.
 * This endpoint only applies to private repositories.
 * For more information, see "[Allowing access to components in a private repository](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-github-actions-settings-for-a-repository#allowing-access-to-components-in-a-private-repository)".
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/permissions/access
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input): Promise<void>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposActionsPermissionsAccess.PutHeader;
    type Input = actions_minus_workflow_minus_access_minus_to_minus_repository;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/actions/permissions/access";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input) => void;
}
