import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRunners } from "../../../../structures/IApiReposActionsRunners";
import { response } from "../../../../structures/response";
import { runner } from "../../../../structures/runner";
export * as downloads from "./downloads";
export * as generate_jitconfig from "./generate_jitconfig";
export * as registration_token from "./registration_token";
export * as remove_token from "./remove_token";
export * as labels from "./labels";
/**
 * List self-hosted runners for a repository.
 * Lists all self-hosted runners configured in a repository.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsRunners.GetHeader;
    type Query = IApiReposActionsRunners.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runners";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, query: getByOwnerAndRepo.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query) => Output;
}
/**
 * Get a self-hosted runner for a repository.
 * Gets a specific self-hosted runner configured in a repository.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRunner_id(connection: IConnection<getByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string): Promise<getByOwnerAndRepoAndRunner_id.Output>;
export declare namespace getByOwnerAndRepoAndRunner_id {
    type Headers = IApiReposActionsRunners.GetHeader;
    type Output = runner;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => runner;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string) => Output;
}
/**
 * Delete a self-hosted runner from a repository.
 * Forces the removal of a self-hosted runner from a repository. You can use this endpoint to completely remove the runner when the machine you were using no longer exists.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRunner_id(connection: IConnection<eraseByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndRunner_id {
    type Headers = IApiReposActionsRunners.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string) => void;
}
