import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRunnersLabels } from "../../../../../structures/IApiReposActionsRunnersLabels";
import { body } from "../../../../../structures/body";
import { response } from "../../../../../structures/response";
/**
 * List labels for a self-hosted runner for a repository.
 * Lists all labels for a self-hosted runner configured in a repository.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRunner_id(connection: IConnection<getByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string): Promise<getByOwnerAndRepoAndRunner_id.Output>;
export declare namespace getByOwnerAndRepoAndRunner_id {
    type Headers = IApiReposActionsRunnersLabels.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id/labels";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string) => Output;
}
/**
 * Add custom labels to a self-hosted runner for a repository.
 * Adds custom labels to a self-hosted runner configured in a repository.
 *
 * Authenticated users must have admin access to the organization to use this endpoint.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndRunner_id(connection: IConnection<postByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string, body: postByOwnerAndRepoAndRunner_id.Input): Promise<postByOwnerAndRepoAndRunner_id.Output>;
export declare namespace postByOwnerAndRepoAndRunner_id {
    type Headers = IApiReposActionsRunnersLabels.PostHeader;
    type Input = body;
    type Output = response;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id/labels";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string, body: postByOwnerAndRepoAndRunner_id.Input) => Output;
}
/**
 * Set custom labels for a self-hosted runner for a repository.
 * Remove all previous custom labels and set the new custom labels for a specific
 * self-hosted runner configured in a repository.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndRunner_id(connection: IConnection<putByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string, body: putByOwnerAndRepoAndRunner_id.Input): Promise<putByOwnerAndRepoAndRunner_id.Output>;
export declare namespace putByOwnerAndRepoAndRunner_id {
    type Headers = IApiReposActionsRunnersLabels.PutHeader;
    type Input = body;
    type Output = response;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id/labels";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<putByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string, body: putByOwnerAndRepoAndRunner_id.Input) => Output;
}
/**
 * Remove all custom labels from a self-hosted runner for a repository.
 * Remove all custom labels from a self-hosted runner configured in a
 * repository. Returns the remaining read-only labels from the runner.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRunner_id(connection: IConnection<eraseByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string): Promise<eraseByOwnerAndRepoAndRunner_id.Output>;
export declare namespace eraseByOwnerAndRepoAndRunner_id {
    type Headers = IApiReposActionsRunnersLabels.DeleteHeader;
    type Output = response;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id/labels";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRunner_id.Headers>, owner: string, repo: string, runner_id: string) => Output;
}
/**
 * Remove a custom label from a self-hosted runner for a repository.
 * Remove a custom label from a self-hosted runner configured
 * in a repository. Returns the remaining labels from the runner.
 *
 * This endpoint returns a `404 Not Found` status if the custom label is not
 * present on the runner.
 *
 * Authenticated users must have admin access to the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runners/:runner_id/labels/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRunner_idAndName(connection: IConnection<eraseByOwnerAndRepoAndRunner_idAndName.Headers>, owner: string, repo: string, runner_id: string, name: string): Promise<eraseByOwnerAndRepoAndRunner_idAndName.Output>;
export declare namespace eraseByOwnerAndRepoAndRunner_idAndName {
    type Headers = IApiReposActionsRunnersLabels.DeleteHeader;
    type Output = response;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/actions/runners/:runner_id/labels/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, runner_id: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRunner_idAndName.Headers>, owner: string, repo: string, runner_id: string, name: string) => Output;
}
