import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRunsPendingDeployments } from "../../../../../structures/IApiReposActionsRunsPendingDeployments";
import { body } from "../../../../../structures/body";
import { deployment } from "../../../../../structures/deployment";
import { pending_minus_deployment } from "../../../../../structures/pending_minus_deployment";
/**
 * Get pending deployments for a workflow run.
 * Get all deployment environments for a workflow run that are waiting for protection rules to pass.
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * If the repository is private, OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id/pending_deployments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRun_id(connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string): Promise<getByOwnerAndRepoAndRun_id.Output>;
export declare namespace getByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRunsPendingDeployments.GetHeader;
    type Output = pending_minus_deployment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id/pending_deployments";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => pending_minus_deployment[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string) => Output;
}
/**
 * Review pending deployments for a workflow run.
 * Approve or reject pending deployments that are waiting on approval by a required reviewer.
 *
 * Required reviewers with read access to the repository contents and deployments can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id/pending_deployments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndRun_id(connection: IConnection<postByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string, body: postByOwnerAndRepoAndRun_id.Input): Promise<postByOwnerAndRepoAndRun_id.Output>;
export declare namespace postByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRunsPendingDeployments.PostHeader;
    type Input = body;
    type Output = deployment[];
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id/pending_deployments";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => deployment[];
    const simulate: (connection: IConnection<postByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string, body: postByOwnerAndRepoAndRun_id.Input) => Output;
}
