import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsRunsTiming } from "../../../../../structures/IApiReposActionsRunsTiming";
import { workflow_minus_run_minus_usage } from "../../../../../structures/workflow_minus_run_minus_usage";
/**
 * Get workflow run usage.
 * Gets the number of billable minutes and total run time for a specific workflow run. Billable minutes only apply to workflows in private repositories that use GitHub-hosted runners. Usage is listed for each GitHub-hosted runner operating system in milliseconds. Any job re-runs are also included in the usage. The usage does not include the multiplier for macOS and Windows runners and is not rounded up to the nearest whole minute. For more information, see "[Managing billing for GitHub Actions](https://docs.github.com/github/setting-up-and-managing-billing-and-payments-on-github/managing-billing-for-github-actions)".
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint with a private repository.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/runs/:run_id/timing
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRun_id(connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string): Promise<getByOwnerAndRepoAndRun_id.Output>;
export declare namespace getByOwnerAndRepoAndRun_id {
    type Headers = IApiReposActionsRunsTiming.GetHeader;
    type Output = workflow_minus_run_minus_usage;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/runs/:run_id/timing";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, run_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => workflow_minus_run_minus_usage;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRun_id.Headers>, owner: string, repo: string, run_id: string) => Output;
}
