import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposActionsWorkflows } from "../../../../structures/IApiReposActionsWorkflows";
import { response } from "../../../../structures/response";
import { workflow } from "../../../../structures/workflow";
export * as disable from "./disable";
export * as dispatches from "./dispatches";
export * as enable from "./enable";
export * as runs from "./runs";
export * as timing from "./timing";
/**
 * List repository workflows.
 * Lists the workflows in a repository.
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint with a private repository.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/workflows
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposActionsWorkflows.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/workflows";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get a workflow.
 * Gets a specific workflow. You can replace `workflow_id` with the workflow
 * file name. For example, you could use `main.yaml`.
 *
 * Anyone with read access to the repository can use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint with a private repository.
 *
 * @tag actions
 * @path repos/:owner/:repo/actions/workflows/:workflow_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndWorkflow_id(connection: IConnection<getByOwnerAndRepoAndWorkflow_id.Headers>, owner: string, repo: string, workflow_id: string): Promise<getByOwnerAndRepoAndWorkflow_id.Output>;
export declare namespace getByOwnerAndRepoAndWorkflow_id {
    type Headers = IApiReposActionsWorkflows.GetHeader;
    type Output = workflow;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/actions/workflows/:workflow_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, workflow_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => workflow;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndWorkflow_id.Headers>, owner: string, repo: string, workflow_id: string) => Output;
}
