import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposAttestations } from "../../../structures/IApiReposAttestations";
import { body } from "../../../structures/body";
import { response } from "../../../structures/response";
/**
 * Create an attestation.
 * Store an artifact attestation and associate it with a repository.
 *
 * The authenticated user must have write permission to the repository and, if using a fine-grained access token the `attestations:write` permission is required.
 *
 * Artifact attestations are meant to be created using the [attest action](https://github.com/actions/attest). For amore information, see our guide on [using artifact attestations to establish a build's provenance](https://docs.github.com/actions/security-guides/using-artifact-attestations-to-establish-provenance-for-builds).
 *
 * @tag repos
 * @path repos/:owner/:repo/attestations
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposAttestations.PostHeader;
    type Input = body;
    type Output = response;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/attestations";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * List attestations.
 * List a collection of artifact attestations with a given subject digest that are associated with a repository.
 *
 * The authenticated user making the request must have read access to the repository. In addition, when using a fine-grained access token the `attestations:read` permission is required.
 *
 * **Please note:** in order to offer meaningful security benefits, an attestation's signature and timestamps **must** be cryptographically verified, and the identity of the attestation signer **must** be validated. Attestations can be verified using the [GitHub CLI `attestation verify` command](https://cli.github.com/manual/gh_attestation_verify). For more information, see [our guide on how to use artifact attestations to establish a build's provenance](https://docs.github.com/actions/security-guides/using-artifact-attestations-to-establish-provenance-for-builds).
 *
 * @param subject_digest The parameter should be set to the attestation's subject's SHA256 digest, in the form `sha256:HEX_DIGEST`.
 * @tag repos
 * @path repos/:owner/:repo/attestations/:subject_digest
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndSubject_digest(connection: IConnection<getByOwnerAndRepoAndSubject_digest.Headers>, owner: string, repo: string, subject_digest: string): Promise<getByOwnerAndRepoAndSubject_digest.Output>;
export declare namespace getByOwnerAndRepoAndSubject_digest {
    type Headers = IApiReposAttestations.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/attestations/:subject_digest";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, subject_digest: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndSubject_digest.Headers>, owner: string, repo: string, subject_digest: string) => Output;
}
