import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposAutomatedSecurityFixes } from "../../../structures/IApiReposAutomatedSecurityFixes";
import { check_minus_automated_minus_security_minus_fixes } from "../../../structures/check_minus_automated_minus_security_minus_fixes";
/**
 * Check if automated security fixes are enabled for a repository.
 * Shows whether automated security fixes are enabled, disabled or paused for a repository. The authenticated user must have admin read access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
 *
 * @tag repos
 * @path repos/:owner/:repo/automated-security-fixes
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposAutomatedSecurityFixes.GetHeader;
    type Output = check_minus_automated_minus_security_minus_fixes;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/automated-security-fixes";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => check_minus_automated_minus_security_minus_fixes;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Enable automated security fixes.
 * Enables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
 *
 * @tag repos
 * @path repos/:owner/:repo/automated-security-fixes
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposAutomatedSecurityFixes.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/automated-security-fixes";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
/**
 * Disable automated security fixes.
 * Disables automated security fixes for a repository. The authenticated user must have admin access to the repository. For more information, see "[Configuring automated security fixes](https://docs.github.com/articles/configuring-automated-security-fixes)".
 *
 * @tag repos
 * @path repos/:owner/:repo/automated-security-fixes
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepo(connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace eraseByOwnerAndRepo {
    type Headers = IApiReposAutomatedSecurityFixes.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/automated-security-fixes";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
