import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposBranchesProtectionRestrictionsApps } from "../../../../../../structures/IApiReposBranchesProtectionRestrictionsApps";
import { body } from "../../../../../../structures/body";
import { integration } from "../../../../../../structures/integration";
/**
 * Get apps with access to the protected branch.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Lists the GitHub Apps that have push access to this branch. Only GitHub Apps that are installed on the repository and that have been granted write access to the repository contents can be added as authorized actors on a protected branch.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/restrictions/apps
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndBranch(connection: IConnection<getByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string): Promise<getByOwnerAndRepoAndBranch.Output>;
export declare namespace getByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRestrictionsApps.GetHeader;
    type Output = integration[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/restrictions/apps";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => integration[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string) => Output;
}
/**
 * Add app access restrictions.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Grants the specified apps push access for this branch. Only GitHub Apps that are installed on the repository and that have been granted write access to the repository contents can be added as authorized actors on a protected branch.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/restrictions/apps
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndBranch(connection: IConnection<postByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: postByOwnerAndRepoAndBranch.Input): Promise<postByOwnerAndRepoAndBranch.Output>;
export declare namespace postByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRestrictionsApps.PostHeader;
    type Input = body;
    type Output = integration[];
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/restrictions/apps";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => integration[];
    const simulate: (connection: IConnection<postByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: postByOwnerAndRepoAndBranch.Input) => Output;
}
/**
 * Set app access restrictions.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Replaces the list of apps that have push access to this branch. This removes all apps that previously had push access and grants push access to the new list of apps. Only GitHub Apps that are installed on the repository and that have been granted write access to the repository contents can be added as authorized actors on a protected branch.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/restrictions/apps
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndBranch(connection: IConnection<putByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: putByOwnerAndRepoAndBranch.Input): Promise<putByOwnerAndRepoAndBranch.Output>;
export declare namespace putByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRestrictionsApps.PutHeader;
    type Input = body;
    type Output = integration[];
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/restrictions/apps";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => integration[];
    const simulate: (connection: IConnection<putByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: putByOwnerAndRepoAndBranch.Input) => Output;
}
/**
 * Remove app access restrictions.
 * Protected branches are available in public repositories with GitHub Free and GitHub Free for organizations, and in public and private repositories with GitHub Pro, GitHub Team, GitHub Enterprise Cloud, and GitHub Enterprise Server. For more information, see [GitHub's products](https://docs.github.com/github/getting-started-with-github/githubs-products) in the GitHub Help documentation.
 *
 * Removes the ability of an app to push to this branch. Only GitHub Apps that are installed on the repository and that have been granted write access to the repository contents can be added as authorized actors on a protected branch.
 *
 * @tag repos
 * @path repos/:owner/:repo/branches/:branch/protection/restrictions/apps
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndBranch(connection: IConnection<eraseByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: eraseByOwnerAndRepoAndBranch.Input): Promise<eraseByOwnerAndRepoAndBranch.Output>;
export declare namespace eraseByOwnerAndRepoAndBranch {
    type Headers = IApiReposBranchesProtectionRestrictionsApps.DeleteHeader;
    type Input = body;
    type Output = integration[];
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/branches/:branch/protection/restrictions/apps";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, branch: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => integration[];
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndBranch.Headers>, owner: string, repo: string, branch: string, body: eraseByOwnerAndRepoAndBranch.Input) => Output;
}
