import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCheckSuites } from "../../../structures/IApiReposCheckSuites";
import { body } from "../../../structures/body";
import { check_minus_suite } from "../../../structures/check_minus_suite";
export * as preferences from "./preferences";
export * as check_runs from "./check_runs";
export * as rerequest from "./rerequest";
/**
 * Create a check suite.
 * Creates a check suite manually. By default, check suites are automatically created when you create a [check run](https://docs.github.com/rest/checks/runs). You only need to use this endpoint for manually creating check suites when you've disabled automatic creation using "[Update repository preferences for check suites](https://docs.github.com/rest/checks/suites#update-repository-preferences-for-check-suites)".
 *
 * > [!NOTE]
 * > The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array and a `null` value for `head_branch`.
 *
 * OAuth apps and personal access tokens (classic) cannot use this endpoint.
 *
 * @tag checks
 * @path repos/:owner/:repo/check-suites
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposCheckSuites.PostHeader;
    type Input = body;
    type Output = check_minus_suite;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/check-suites";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => check_minus_suite;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a check suite.
 * Gets a single check suite using its `id`.
 *
 * > [!NOTE]
 * > The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty `pull_requests` array and a `null` value for `head_branch`.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint on a private repository.
 *
 * @tag checks
 * @path repos/:owner/:repo/check-suites/:check_suite_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndCheck_suite_id(connection: IConnection<getByOwnerAndRepoAndCheck_suite_id.Headers>, owner: string, repo: string, check_suite_id: string): Promise<getByOwnerAndRepoAndCheck_suite_id.Output>;
export declare namespace getByOwnerAndRepoAndCheck_suite_id {
    type Headers = IApiReposCheckSuites.GetHeader;
    type Output = check_minus_suite;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/check-suites/:check_suite_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, check_suite_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => check_minus_suite;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndCheck_suite_id.Headers>, owner: string, repo: string, check_suite_id: string) => Output;
}
