import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiReposCodeScanningCodeqlVariantAnalyses } from "../../../../../structures/IApiReposCodeScanningCodeqlVariantAnalyses";
import { code_minus_scanning_minus_variant_minus_analysis } from "../../../../../structures/code_minus_scanning_minus_variant_minus_analysis";
export * as repos from "./repos";
/**
 * Create a CodeQL variant analysis.
 * Creates a new CodeQL variant analysis, which will run a CodeQL query against one or more repositories.
 *
 * Get started by learning more about [running CodeQL queries at scale with Multi-Repository Variant Analysis](https://docs.github.com/code-security/codeql-for-vs-code/getting-started-with-codeql-for-vs-code/running-codeql-queries-at-scale-with-multi-repository-variant-analysis).
 *
 * Use the `owner` and `repo` parameters in the URL to specify the controller repository that
 * will be used for running GitHub Actions workflows and storing the results of the CodeQL variant analysis.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/codeql/variant-analyses
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposCodeScanningCodeqlVariantAnalyses.PostHeader;
    type Input = any | any | any;
    type Output = code_minus_scanning_minus_variant_minus_analysis;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/code-scanning/codeql/variant-analyses";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_variant_minus_analysis;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get the summary of a CodeQL variant analysis.
 * Gets the summary of a CodeQL variant analysis.
 *
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint with private or public repositories, or the `public_repo` scope to use this endpoint with only public repositories.
 *
 * @param codeql_variant_analysis_id The unique identifier of the variant analysis.
 * @tag code-scanning
 * @path repos/:owner/:repo/code-scanning/codeql/variant-analyses/:codeql_variant_analysis_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndCodeql_variant_analysis_id(connection: IConnection<getByOwnerAndRepoAndCodeql_variant_analysis_id.Headers>, owner: string, repo: string, codeql_variant_analysis_id: number & tags.Type<"int32">): Promise<getByOwnerAndRepoAndCodeql_variant_analysis_id.Output>;
export declare namespace getByOwnerAndRepoAndCodeql_variant_analysis_id {
    type Headers = IApiReposCodeScanningCodeqlVariantAnalyses.GetHeader;
    type Output = code_minus_scanning_minus_variant_minus_analysis;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/code-scanning/codeql/variant-analyses/:codeql_variant_analysis_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, codeql_variant_analysis_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => code_minus_scanning_minus_variant_minus_analysis;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndCodeql_variant_analysis_id.Headers>, owner: string, repo: string, codeql_variant_analysis_id: number & tags.Type<"int32">) => Output;
}
