import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCodespacesSecrets } from "../../../../structures/IApiReposCodespacesSecrets";
import { body } from "../../../../structures/body";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { repo_minus_codespaces_minus_secret } from "../../../../structures/repo_minus_codespaces_minus_secret";
import { response } from "../../../../structures/response";
export * as public_key from "./public_key";
/**
 * List repository secrets.
 * Lists all development environment secrets available in a repository without revealing their encrypted
 * values.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag codespaces
 * @path repos/:owner/:repo/codespaces/secrets
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposCodespacesSecrets.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/codespaces/secrets";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get a repository secret.
 * Gets a single repository development environment secret without revealing its encrypted value.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag codespaces
 * @path repos/:owner/:repo/codespaces/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndSecret_name(connection: IConnection<getByOwnerAndRepoAndSecret_name.Headers>, owner: string, repo: string, secret_name: string): Promise<getByOwnerAndRepoAndSecret_name.Output>;
export declare namespace getByOwnerAndRepoAndSecret_name {
    type Headers = IApiReposCodespacesSecrets.GetHeader;
    type Output = repo_minus_codespaces_minus_secret;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/codespaces/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => repo_minus_codespaces_minus_secret;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndSecret_name.Headers>, owner: string, repo: string, secret_name: string) => Output;
}
/**
 * Create or update a repository secret.
 * Creates or updates a repository development environment secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). For more information, see "[Encrypting secrets for the REST API](https://docs.github.com/rest/guides/encrypting-secrets-for-the-rest-api)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag codespaces
 * @path repos/:owner/:repo/codespaces/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndSecret_name(connection: IConnection<putByOwnerAndRepoAndSecret_name.Headers>, owner: string, repo: string, secret_name: string, body: putByOwnerAndRepoAndSecret_name.Input): Promise<putByOwnerAndRepoAndSecret_name.Output>;
export declare namespace putByOwnerAndRepoAndSecret_name {
    type Headers = IApiReposCodespacesSecrets.PutHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/codespaces/secrets/:secret_name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<putByOwnerAndRepoAndSecret_name.Headers>, owner: string, repo: string, secret_name: string, body: putByOwnerAndRepoAndSecret_name.Input) => Output;
}
/**
 * Delete a repository secret.
 * Deletes a development environment secret in a repository using the secret name.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag codespaces
 * @path repos/:owner/:repo/codespaces/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndSecret_name(connection: IConnection<eraseByOwnerAndRepoAndSecret_name.Headers>, owner: string, repo: string, secret_name: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndSecret_name {
    type Headers = IApiReposCodespacesSecrets.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/codespaces/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndSecret_name.Headers>, owner: string, repo: string, secret_name: string) => void;
}
