import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposComments } from "../../../structures/IApiReposComments";
import { body } from "../../../structures/body";
import { commit_minus_comment } from "../../../structures/commit_minus_comment";
export * as reactions from "./reactions";
/**
 * List commit comments for a repository.
 * Lists the commit comments for a specified repository. Comments are ordered by ascending ID.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag repos
 * @path repos/:owner/:repo/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposComments.GetHeader;
    type Output = commit_minus_comment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/comments";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => commit_minus_comment[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get a commit comment.
 * Gets a specified commit comment.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag repos
 * @path repos/:owner/:repo/comments/:comment_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndComment_id(connection: IConnection<getByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string): Promise<getByOwnerAndRepoAndComment_id.Output>;
export declare namespace getByOwnerAndRepoAndComment_id {
    type Headers = IApiReposComments.GetHeader;
    type Output = commit_minus_comment;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/comments/:comment_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => commit_minus_comment;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string) => Output;
}
/**
 * Update a commit comment.
 * Updates the contents of a specified commit comment.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag repos
 * @path repos/:owner/:repo/comments/:comment_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndComment_id(connection: IConnection<patchByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string, body: patchByOwnerAndRepoAndComment_id.Input): Promise<patchByOwnerAndRepoAndComment_id.Output>;
export declare namespace patchByOwnerAndRepoAndComment_id {
    type Headers = IApiReposComments.PatchHeader;
    type Input = body;
    type Output = commit_minus_comment;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/comments/:comment_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => commit_minus_comment;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string, body: patchByOwnerAndRepoAndComment_id.Input) => Output;
}
/**
 * @tag repos
 * @path repos/:owner/:repo/comments/:comment_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndComment_id(connection: IConnection<eraseByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndComment_id {
    type Headers = IApiReposComments.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/comments/:comment_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, comment_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndComment_id.Headers>, owner: string, repo: string, comment_id: string) => void;
}
