import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCommitsComments } from "../../../../structures/IApiReposCommitsComments";
import { body } from "../../../../structures/body";
import { commit_minus_comment } from "../../../../structures/commit_minus_comment";
/**
 * List commit comments.
 * Lists the comments for a specified commit.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag repos
 * @path repos/:owner/:repo/commits/:commit_sha/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndCommit_sha(connection: IConnection<getByOwnerAndRepoAndCommit_sha.Headers>, owner: string, repo: string, commit_sha: string): Promise<getByOwnerAndRepoAndCommit_sha.Output>;
export declare namespace getByOwnerAndRepoAndCommit_sha {
    type Headers = IApiReposCommitsComments.GetHeader;
    type Output = commit_minus_comment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/commits/:commit_sha/comments";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, commit_sha: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => commit_minus_comment[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndCommit_sha.Headers>, owner: string, repo: string, commit_sha: string) => Output;
}
/**
 * Create a commit comment.
 * Create a comment for a commit using its `:commit_sha`.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag repos
 * @path repos/:owner/:repo/commits/:commit_sha/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndCommit_sha(connection: IConnection<postByOwnerAndRepoAndCommit_sha.Headers>, owner: string, repo: string, commit_sha: string, body: postByOwnerAndRepoAndCommit_sha.Input): Promise<postByOwnerAndRepoAndCommit_sha.Output>;
export declare namespace postByOwnerAndRepoAndCommit_sha {
    type Headers = IApiReposCommitsComments.PostHeader;
    type Input = body;
    type Output = commit_minus_comment;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/commits/:commit_sha/comments";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, commit_sha: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => commit_minus_comment;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndCommit_sha.Headers>, owner: string, repo: string, commit_sha: string, body: postByOwnerAndRepoAndCommit_sha.Input) => Output;
}
