import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposCommunityProfile } from "../../../../structures/IApiReposCommunityProfile";
import { community_minus_profile } from "../../../../structures/community_minus_profile";
/**
 * Get community profile metrics.
 * Returns all community profile metrics for a repository. The repository cannot be a fork.
 *
 * The returned metrics include an overall health score, the repository description, the presence of documentation, the
 * detected code of conduct, the detected license, and the presence of ISSUE\_TEMPLATE, PULL\_REQUEST\_TEMPLATE,
 * README, and CONTRIBUTING files.
 *
 * The `health_percentage` score is defined as a percentage of how many of
 * the recommended community health files are present. For more information, see
 * "[About community profiles for public repositories](https://docs.github.com/communities/setting-up-your-project-for-healthy-contributions/about-community-profiles-for-public-repositories)."
 *
 * `content_reports_enabled` is only returned for organization-owned repositories.
 *
 * @tag repos
 * @path repos/:owner/:repo/community/profile
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposCommunityProfile.GetHeader;
    type Output = community_minus_profile;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/community/profile";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => community_minus_profile;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
