import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposContents } from "../../../structures/IApiReposContents";
import { body } from "../../../structures/body";
import { content_minus_directory } from "../../../structures/content_minus_directory";
import { content_minus_file } from "../../../structures/content_minus_file";
import { content_minus_submodule } from "../../../structures/content_minus_submodule";
import { content_minus_symlink } from "../../../structures/content_minus_symlink";
import { file_minus_commit } from "../../../structures/file_minus_commit";
/**
 * Get repository content.
 * Gets the contents of a file or directory in a repository. Specify the file path or directory with the `path` parameter. If you omit the `path` parameter, you will receive the contents of the repository's root directory.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw file contents for files and symlinks.
 * - **`application/vnd.github.html+json`**: Returns the file contents in HTML. Markup languages are rendered to HTML using GitHub's open-source [Markup library](https://github.com/github/markup).
 * - **`application/vnd.github.object+json`**: Returns the contents in a consistent object format regardless of the content type. For example, instead of an array of objects for a directory, the response will be an object with an `entries` attribute containing the array of objects.
 *
 * If the content is a directory, the response will be an array of objects, one object for each item in the directory. When listing the contents of a directory, submodules have their "type" specified as "file". Logically, the value _should_ be "submodule". This behavior exists [for backwards compatibility purposes](https://git.io/v1YCW). In the next major version of the API, the type will be returned as "submodule".
 *
 * If the content is a symlink and the symlink's target is a normal file in the repository, then the API responds with the content of the file. Otherwise, the API responds with an object describing the symlink itself.
 *
 * If the content is a submodule, the `submodule_git_url` field identifies the location of the submodule repository, and the `sha` identifies a specific commit within the submodule repository. Git uses the given URL when cloning the submodule repository, and checks out the submodule at that specific commit. If the submodule repository is not hosted on github.com, the Git URLs (`git_url` and `_links["git"]`) and the github.com URLs (`html_url` and `_links["html"]`) will have null values.
 *
 * **Notes**:
 *
 * - To get a repository's contents recursively, you can [recursively get the tree](https://docs.github.com/rest/git/trees#get-a-tree).
 * - This API has an upper limit of 1,000 files for a directory. If you need to retrieve
 * more files, use the [Git Trees API](https://docs.github.com/rest/git/trees#get-a-tree).
 * - Download URLs expire and are meant to be used just once. To ensure the download URL does not expire, please use the contents API to obtain a fresh download URL for each download.
 * - If the requested file's size is:
 * - 1 MB or smaller: All features of this endpoint are supported.
 * - Between 1-100 MB: Only the `raw` or `object` custom media types are supported. Both will work as normal, except that when using the `object` media type, the `content` field will be an empty
 * string and the `encoding` field will be `"none"`. To get the contents of these larger files, use the `raw` media type.
 * - Greater than 100 MB: This endpoint is not supported.
 *
 * @param path path parameter
 * @tag repos
 * @path repos/:owner/:repo/contents/:path
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndPath(connection: IConnection<getByOwnerAndRepoAndPath.Headers>, owner: string, repo: string, path: string, query: getByOwnerAndRepoAndPath.Query): Promise<getByOwnerAndRepoAndPath.Output>;
export declare namespace getByOwnerAndRepoAndPath {
    type Headers = IApiReposContents.GetHeader;
    type Query = IApiReposContents.GetQuery;
    type Output = content_minus_directory | content_minus_file | content_minus_symlink | content_minus_submodule;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/contents/:path";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, path: string, query: getByOwnerAndRepoAndPath.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => content_minus_directory | content_minus_file | content_minus_symlink | content_minus_submodule;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndPath.Headers>, owner: string, repo: string, path: string, query: getByOwnerAndRepoAndPath.Query) => Output;
}
/**
 * Create or update file contents.
 * Creates a new file or replaces an existing file in a repository.
 *
 * > [!NOTE]
 * > If you use this endpoint and the "[Delete a file](https://docs.github.com/rest/repos/contents/#delete-a-file)" endpoint in parallel, the concurrent requests will conflict and you will receive errors. You must use these endpoints serially instead.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint. The `workflow` scope is also required in order to modify files in the `.github/workflows` directory.
 *
 * @param path path parameter
 * @tag repos
 * @path repos/:owner/:repo/contents/:path
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndPath(connection: IConnection<putByOwnerAndRepoAndPath.Headers>, owner: string, repo: string, path: string, body: putByOwnerAndRepoAndPath.Input): Promise<putByOwnerAndRepoAndPath.Output>;
export declare namespace putByOwnerAndRepoAndPath {
    type Headers = IApiReposContents.PutHeader;
    type Input = body;
    type Output = file_minus_commit;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/contents/:path";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, path: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => file_minus_commit;
    const simulate: (connection: IConnection<putByOwnerAndRepoAndPath.Headers>, owner: string, repo: string, path: string, body: putByOwnerAndRepoAndPath.Input) => Output;
}
/**
 * Delete a file.
 * Deletes a file in a repository.
 *
 * You can provide an additional `committer` parameter, which is an object containing information about the committer. Or, you can provide an `author` parameter, which is an object containing information about the author.
 *
 * The `author` section is optional and is filled in with the `committer` information if omitted. If the `committer` information is omitted, the authenticated user's information is used.
 *
 * You must provide values for both `name` and `email`, whether you choose to use `author` or `committer`. Otherwise, you'll receive a `422` status code.
 *
 * > [!NOTE]
 * > If you use this endpoint and the "[Create or update file contents](https://docs.github.com/rest/repos/contents/#create-or-update-file-contents)" endpoint in parallel, the concurrent requests will conflict and you will receive errors. You must use these endpoints serially instead.
 *
 * @param path path parameter
 * @tag repos
 * @path repos/:owner/:repo/contents/:path
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndPath(connection: IConnection<eraseByOwnerAndRepoAndPath.Headers>, owner: string, repo: string, path: string, body: eraseByOwnerAndRepoAndPath.Input): Promise<eraseByOwnerAndRepoAndPath.Output>;
export declare namespace eraseByOwnerAndRepoAndPath {
    type Headers = IApiReposContents.DeleteHeader;
    type Input = body;
    type Output = file_minus_commit;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/contents/:path";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, path: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => file_minus_commit;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndPath.Headers>, owner: string, repo: string, path: string, body: eraseByOwnerAndRepoAndPath.Input) => Output;
}
