import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposDependabotAlerts } from "../../../../structures/IApiReposDependabotAlerts";
import { body } from "../../../../structures/body";
import { dependabot_minus_alert } from "../../../../structures/dependabot_minus_alert";
/**
 * List Dependabot alerts for a repository.
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the `public_repo` scope instead.
 *
 * @tag dependabot
 * @path repos/:owner/:repo/dependabot/alerts
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposDependabotAlerts.GetHeader;
    type Query = IApiReposDependabotAlerts.GetQuery;
    type Output = dependabot_minus_alert[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/dependabot/alerts";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, query: getByOwnerAndRepo.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => dependabot_minus_alert[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query) => Output;
}
/**
 * Get a Dependabot alert.
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the `public_repo` scope instead.
 *
 * @tag dependabot
 * @path repos/:owner/:repo/dependabot/alerts/:alert_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndAlert_number(connection: IConnection<getByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string): Promise<getByOwnerAndRepoAndAlert_number.Output>;
export declare namespace getByOwnerAndRepoAndAlert_number {
    type Headers = IApiReposDependabotAlerts.GetHeader;
    type Output = dependabot_minus_alert;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/dependabot/alerts/:alert_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, alert_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => dependabot_minus_alert;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string) => Output;
}
/**
 * Update a Dependabot alert.
 * The authenticated user must have access to security alerts for the repository to use this endpoint. For more information, see "[Granting access to security alerts](https://docs.github.com/repositories/managing-your-repositorys-settings-and-features/enabling-features-for-your-repository/managing-security-and-analysis-settings-for-your-repository#granting-access-to-security-alerts)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `security_events` scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the `public_repo` scope instead.
 *
 * @tag dependabot
 * @path repos/:owner/:repo/dependabot/alerts/:alert_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndAlert_number(connection: IConnection<patchByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string, body: patchByOwnerAndRepoAndAlert_number.Input): Promise<patchByOwnerAndRepoAndAlert_number.Output>;
export declare namespace patchByOwnerAndRepoAndAlert_number {
    type Headers = IApiReposDependabotAlerts.PatchHeader;
    type Input = body;
    type Output = dependabot_minus_alert;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/dependabot/alerts/:alert_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, alert_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => dependabot_minus_alert;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string, body: patchByOwnerAndRepoAndAlert_number.Input) => Output;
}
