import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposEnvironmentsSecrets } from "../../../../structures/IApiReposEnvironmentsSecrets";
import { actions_minus_secret } from "../../../../structures/actions_minus_secret";
import { body } from "../../../../structures/body";
import { empty_minus_object } from "../../../../structures/empty_minus_object";
import { response } from "../../../../structures/response";
export * as public_key from "./public_key";
/**
 * List environment secrets.
 * Lists all secrets available in an environment without revealing their
 * encrypted values.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/secrets
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndEnvironment_name(connection: IConnection<getByOwnerAndRepoAndEnvironment_name.Headers>, owner: string, repo: string, environment_name: string): Promise<getByOwnerAndRepoAndEnvironment_name.Output>;
export declare namespace getByOwnerAndRepoAndEnvironment_name {
    type Headers = IApiReposEnvironmentsSecrets.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/secrets";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndEnvironment_name.Headers>, owner: string, repo: string, environment_name: string) => Output;
}
/**
 * Get an environment secret.
 * Gets a single environment secret without revealing its encrypted value.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndEnvironment_nameAndSecret_name(connection: IConnection<getByOwnerAndRepoAndEnvironment_nameAndSecret_name.Headers>, owner: string, repo: string, environment_name: string, secret_name: string): Promise<getByOwnerAndRepoAndEnvironment_nameAndSecret_name.Output>;
export declare namespace getByOwnerAndRepoAndEnvironment_nameAndSecret_name {
    type Headers = IApiReposEnvironmentsSecrets.GetHeader;
    type Output = actions_minus_secret;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => actions_minus_secret;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndEnvironment_nameAndSecret_name.Headers>, owner: string, repo: string, environment_name: string, secret_name: string) => Output;
}
/**
 * Create or update an environment secret.
 * Creates or updates an environment secret with an encrypted value. Encrypt your secret using
 * [LibSodium](https://libsodium.gitbook.io/doc/bindings_for_other_languages). For more information, see "[Encrypting secrets for the REST API](https://docs.github.com/rest/guides/encrypting-secrets-for-the-rest-api)."
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndEnvironment_nameAndSecret_name(connection: IConnection<putByOwnerAndRepoAndEnvironment_nameAndSecret_name.Headers>, owner: string, repo: string, environment_name: string, secret_name: string, body: putByOwnerAndRepoAndEnvironment_nameAndSecret_name.Input): Promise<putByOwnerAndRepoAndEnvironment_nameAndSecret_name.Output>;
export declare namespace putByOwnerAndRepoAndEnvironment_nameAndSecret_name {
    type Headers = IApiReposEnvironmentsSecrets.PutHeader;
    type Input = body;
    type Output = empty_minus_object;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/secrets/:secret_name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => empty_minus_object;
    const simulate: (connection: IConnection<putByOwnerAndRepoAndEnvironment_nameAndSecret_name.Headers>, owner: string, repo: string, environment_name: string, secret_name: string, body: putByOwnerAndRepoAndEnvironment_nameAndSecret_name.Input) => Output;
}
/**
 * Delete an environment secret.
 * Deletes a secret in an environment using the secret name.
 *
 * Authenticated users must have collaborator access to a repository to create, update, or read secrets.
 *
 * OAuth tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag actions
 * @path repos/:owner/:repo/environments/:environment_name/secrets/:secret_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndEnvironment_nameAndSecret_name(connection: IConnection<eraseByOwnerAndRepoAndEnvironment_nameAndSecret_name.Headers>, owner: string, repo: string, environment_name: string, secret_name: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndEnvironment_nameAndSecret_name {
    type Headers = IApiReposEnvironmentsSecrets.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/environments/:environment_name/secrets/:secret_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, environment_name: string, secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndEnvironment_nameAndSecret_name.Headers>, owner: string, repo: string, environment_name: string, secret_name: string) => void;
}
