import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposHooksConfig } from "../../../../structures/IApiReposHooksConfig";
import { body } from "../../../../structures/body";
import { webhook_minus_config } from "../../../../structures/webhook_minus_config";
/**
 * Get a webhook configuration for a repository.
 * Returns the webhook configuration for a repository. To get more information about the webhook, including the `active` state and `events`, use "[Get a repository webhook](/rest/webhooks/repos#get-a-repository-webhook)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:repo_hook` or `repo` scope to use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/hooks/:hook_id/config
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndHook_id(connection: IConnection<getByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string): Promise<getByOwnerAndRepoAndHook_id.Output>;
export declare namespace getByOwnerAndRepoAndHook_id {
    type Headers = IApiReposHooksConfig.GetHeader;
    type Output = webhook_minus_config;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/hooks/:hook_id/config";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => webhook_minus_config;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string) => Output;
}
/**
 * Update a webhook configuration for a repository.
 * Updates the webhook configuration for a repository. To update more information about the webhook, including the `active` state and `events`, use "[Update a repository webhook](/rest/webhooks/repos#update-a-repository-webhook)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:repo_hook` or `repo` scope to use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/hooks/:hook_id/config
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndHook_id(connection: IConnection<patchByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string, body: patchByOwnerAndRepoAndHook_id.Input): Promise<patchByOwnerAndRepoAndHook_id.Output>;
export declare namespace patchByOwnerAndRepoAndHook_id {
    type Headers = IApiReposHooksConfig.PatchHeader;
    type Input = body;
    type Output = webhook_minus_config;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/hooks/:hook_id/config";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => webhook_minus_config;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string, body: patchByOwnerAndRepoAndHook_id.Input) => Output;
}
