import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposHooks } from "../../../structures/IApiReposHooks";
import { body } from "../../../structures/body";
import { hook } from "../../../structures/hook";
export * as config from "./config";
export * as deliveries from "./deliveries";
export * as pings from "./pings";
export * as tests from "./tests";
/**
 * List repository webhooks.
 * Lists webhooks for a repository. `last response` may return null if there have not been any deliveries within 30 days.
 *
 * @tag repos
 * @path repos/:owner/:repo/hooks
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposHooks.GetHeader;
    type Output = hook[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/hooks";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hook[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create a repository webhook.
 * Repositories can have multiple webhooks installed. Each webhook should have a unique `config`. Multiple webhooks can
 * share the same `config` as long as those webhooks do not have any `events` that overlap.
 *
 * @tag repos
 * @path repos/:owner/:repo/hooks
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposHooks.PostHeader;
    type Input = body;
    type Output = hook;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/hooks";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hook;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a repository webhook.
 * Returns a webhook configured in a repository. To get only the webhook `config` properties, see "[Get a webhook configuration for a repository](/rest/webhooks/repo-config#get-a-webhook-configuration-for-a-repository)."
 *
 * @tag repos
 * @path repos/:owner/:repo/hooks/:hook_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndHook_id(connection: IConnection<getByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string): Promise<getByOwnerAndRepoAndHook_id.Output>;
export declare namespace getByOwnerAndRepoAndHook_id {
    type Headers = IApiReposHooks.GetHeader;
    type Output = hook;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/hooks/:hook_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hook;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string) => Output;
}
/**
 * Update a repository webhook.
 * Updates a webhook configured in a repository. If you previously had a `secret` set, you must provide the same `secret` or set a new `secret` or the secret will be removed. If you are only updating individual webhook `config` properties, use "[Update a webhook configuration for a repository](/rest/webhooks/repo-config#update-a-webhook-configuration-for-a-repository)."
 *
 * @tag repos
 * @path repos/:owner/:repo/hooks/:hook_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndHook_id(connection: IConnection<patchByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string, body: patchByOwnerAndRepoAndHook_id.Input): Promise<patchByOwnerAndRepoAndHook_id.Output>;
export declare namespace patchByOwnerAndRepoAndHook_id {
    type Headers = IApiReposHooks.PatchHeader;
    type Input = body;
    type Output = hook;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/hooks/:hook_id";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hook;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string, body: patchByOwnerAndRepoAndHook_id.Input) => Output;
}
/**
 * @tag repos
 * @path repos/:owner/:repo/hooks/:hook_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndHook_id(connection: IConnection<eraseByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndHook_id {
    type Headers = IApiReposHooks.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/hooks/:hook_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, hook_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndHook_id.Headers>, owner: string, repo: string, hook_id: string) => void;
}
