import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposIssuesReactions } from "../../../../structures/IApiReposIssuesReactions";
import { body } from "../../../../structures/body";
import { reaction } from "../../../../structures/reaction";
/**
 * List reactions for an issue.
 * List the reactions to an [issue](https://docs.github.com/rest/issues/issues#get-an-issue).
 *
 * @tag reactions
 * @path repos/:owner/:repo/issues/:issue_number/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndIssue_number(connection: IConnection<getByOwnerAndRepoAndIssue_number.Headers>, owner: string, repo: string, issue_number: string, query: getByOwnerAndRepoAndIssue_number.Query): Promise<getByOwnerAndRepoAndIssue_number.Output>;
export declare namespace getByOwnerAndRepoAndIssue_number {
    type Headers = IApiReposIssuesReactions.GetHeader;
    type Query = IApiReposIssuesReactions.GetQuery;
    type Output = reaction[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/issues/:issue_number/reactions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, issue_number: string, query: getByOwnerAndRepoAndIssue_number.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndIssue_number.Headers>, owner: string, repo: string, issue_number: string, query: getByOwnerAndRepoAndIssue_number.Query) => Output;
}
/**
 * Create reaction for an issue.
 * Create a reaction to an [issue](https://docs.github.com/rest/issues/issues#get-an-issue). A response with an HTTP `200` status means that you already added the reaction type to this issue.
 *
 * @tag reactions
 * @path repos/:owner/:repo/issues/:issue_number/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndIssue_number(connection: IConnection<postByOwnerAndRepoAndIssue_number.Headers>, owner: string, repo: string, issue_number: string, body: postByOwnerAndRepoAndIssue_number.Input): Promise<postByOwnerAndRepoAndIssue_number.Output>;
export declare namespace postByOwnerAndRepoAndIssue_number {
    type Headers = IApiReposIssuesReactions.PostHeader;
    type Input = body;
    type Output = reaction;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/issues/:issue_number/reactions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, issue_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndIssue_number.Headers>, owner: string, repo: string, issue_number: string, body: postByOwnerAndRepoAndIssue_number.Input) => Output;
}
/**
 * Delete an issue reaction.
 * > [!NOTE]
 * > You can also specify a repository by `repository_id` using the route `DELETE /repositories/:repository_id/issues/:issue_number/reactions/:reaction_id`.
 *
 * Delete a reaction to an [issue](https://docs.github.com/rest/issues/issues#get-an-issue).
 *
 * @tag reactions
 * @path repos/:owner/:repo/issues/:issue_number/reactions/:reaction_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndIssue_numberAndReaction_id(connection: IConnection<eraseByOwnerAndRepoAndIssue_numberAndReaction_id.Headers>, owner: string, repo: string, issue_number: string, reaction_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndIssue_numberAndReaction_id {
    type Headers = IApiReposIssuesReactions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/issues/:issue_number/reactions/:reaction_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, issue_number: string, reaction_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndIssue_numberAndReaction_id.Headers>, owner: string, repo: string, issue_number: string, reaction_id: string) => void;
}
