import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposLabels } from "../../../structures/IApiReposLabels";
import { body } from "../../../structures/body";
import { label } from "../../../structures/label";
/**
 * List labels for a repository.
 * Lists all labels for a repository.
 *
 * @tag issues
 * @path repos/:owner/:repo/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposLabels.GetHeader;
    type Output = label[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/labels";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => label[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create a label.
 * Creates a label for the specified repository with the given name and color. The name and color parameters are required. The color must be a valid [hexadecimal color code](http://www.color-hex.com/).
 *
 * @tag issues
 * @path repos/:owner/:repo/labels
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposLabels.PostHeader;
    type Input = body;
    type Output = label;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/labels";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => label;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a label.
 * Gets a label using the given name.
 *
 * @tag issues
 * @path repos/:owner/:repo/labels/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndName(connection: IConnection<getByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string): Promise<getByOwnerAndRepoAndName.Output>;
export declare namespace getByOwnerAndRepoAndName {
    type Headers = IApiReposLabels.GetHeader;
    type Output = label;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/labels/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => label;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string) => Output;
}
/**
 * Update a label.
 * Updates a label using the given label name.
 *
 * @tag issues
 * @path repos/:owner/:repo/labels/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndName(connection: IConnection<patchByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string, body: patchByOwnerAndRepoAndName.Input): Promise<patchByOwnerAndRepoAndName.Output>;
export declare namespace patchByOwnerAndRepoAndName {
    type Headers = IApiReposLabels.PatchHeader;
    type Input = body;
    type Output = label;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/labels/:name";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => label;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string, body: patchByOwnerAndRepoAndName.Input) => Output;
}
/**
 * Delete a label.
 * Deletes a label using the given label name.
 *
 * @tag issues
 * @path repos/:owner/:repo/labels/:name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndName(connection: IConnection<eraseByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndName {
    type Headers = IApiReposLabels.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/labels/:name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndName.Headers>, owner: string, repo: string, name: string) => void;
}
