import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposLicense } from "../../../structures/IApiReposLicense";
import { license_minus_content } from "../../../structures/license_minus_content";
/**
 * Get the license for a repository.
 * This method returns the contents of the repository's license file, if one is detected.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw contents of the license.
 * - **`application/vnd.github.html+json`**: Returns the license contents in HTML. Markup languages are rendered to HTML using GitHub's open-source [Markup library](https://github.com/github/markup).
 *
 * @tag licenses
 * @path repos/:owner/:repo/license
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposLicense.GetHeader;
    type Output = license_minus_content;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/license";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => license_minus_content;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
