import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposMilestones } from "../../../structures/IApiReposMilestones";
import { body } from "../../../structures/body";
import { milestone } from "../../../structures/milestone";
export * as labels from "./labels";
/**
 * List milestones.
 * Lists milestones for a repository.
 *
 * @tag issues
 * @path repos/:owner/:repo/milestones
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposMilestones.GetHeader;
    type Query = IApiReposMilestones.GetQuery;
    type Output = milestone[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/milestones";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, query: getByOwnerAndRepo.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => milestone[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query) => Output;
}
/**
 * Create a milestone.
 * Creates a milestone.
 *
 * @tag issues
 * @path repos/:owner/:repo/milestones
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposMilestones.PostHeader;
    type Input = body;
    type Output = milestone;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/milestones";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => milestone;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string, body: postByOwnerAndRepo.Input) => Output;
}
/**
 * Get a milestone.
 * Gets a milestone using the given milestone number.
 *
 * @tag issues
 * @path repos/:owner/:repo/milestones/:milestone_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndMilestone_number(connection: IConnection<getByOwnerAndRepoAndMilestone_number.Headers>, owner: string, repo: string, milestone_number: string): Promise<getByOwnerAndRepoAndMilestone_number.Output>;
export declare namespace getByOwnerAndRepoAndMilestone_number {
    type Headers = IApiReposMilestones.GetHeader;
    type Output = milestone;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/milestones/:milestone_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, milestone_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => milestone;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndMilestone_number.Headers>, owner: string, repo: string, milestone_number: string) => Output;
}
/**
 * @tag issues
 * @path repos/:owner/:repo/milestones/:milestone_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndMilestone_number(connection: IConnection<patchByOwnerAndRepoAndMilestone_number.Headers>, owner: string, repo: string, milestone_number: string, body: patchByOwnerAndRepoAndMilestone_number.Input): Promise<patchByOwnerAndRepoAndMilestone_number.Output>;
export declare namespace patchByOwnerAndRepoAndMilestone_number {
    type Headers = IApiReposMilestones.PatchHeader;
    type Input = body;
    type Output = milestone;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/milestones/:milestone_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, milestone_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => milestone;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndMilestone_number.Headers>, owner: string, repo: string, milestone_number: string, body: patchByOwnerAndRepoAndMilestone_number.Input) => Output;
}
/**
 * Delete a milestone.
 * Deletes a milestone using the given milestone number.
 *
 * @tag issues
 * @path repos/:owner/:repo/milestones/:milestone_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndMilestone_number(connection: IConnection<eraseByOwnerAndRepoAndMilestone_number.Headers>, owner: string, repo: string, milestone_number: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndMilestone_number {
    type Headers = IApiReposMilestones.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/milestones/:milestone_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, milestone_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndMilestone_number.Headers>, owner: string, repo: string, milestone_number: string) => void;
}
