import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposNotifications } from "../../../structures/IApiReposNotifications";
import { body } from "../../../structures/body";
import { thread } from "../../../structures/thread";
/**
 * List repository notifications for the authenticated user.
 * Lists all notifications for the current user in the specified repository.
 *
 * @tag activity
 * @path repos/:owner/:repo/notifications
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposNotifications.GetHeader;
    type Output = thread[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/notifications";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => thread[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Mark repository notifications as read.
 * Marks all notifications in a repository as "read" for the current user. If the number of notifications is too large to complete in one request, you will receive a `202 Accepted` status and GitHub will run an asynchronous process to mark notifications as "read." To check whether any "unread" notifications remain, you can use the [List repository notifications for the authenticated user](https://docs.github.com/rest/activity/notifications#list-repository-notifications-for-the-authenticated-user) endpoint and pass the query parameter `all=false`.
 *
 * @tag activity
 * @path repos/:owner/:repo/notifications
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input): Promise<void>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposNotifications.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/notifications";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input) => void;
}
