import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiReposPagesBuilds } from "../../../../structures/IApiReposPagesBuilds";
import { page_minus_build } from "../../../../structures/page_minus_build";
import { page_minus_build_minus_status } from "../../../../structures/page_minus_build_minus_status";
export * as latest from "./latest";
/**
 * List GitHub Pages builds.
 * Lists builts of a GitHub Pages site.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/pages/builds
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposPagesBuilds.GetHeader;
    type Output = page_minus_build[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/pages/builds";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => page_minus_build[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Request a GitHub Pages build.
 * You can request that your site be built from the latest revision on the default branch. This has the same effect as pushing a commit to your default branch, but does not require an additional commit. Manually triggering page builds can be helpful when diagnosing build warnings and failures.
 *
 * Build requests are limited to one concurrent build per repository and one concurrent build per requester. If you request a build while another is still in progress, the second request will be queued until the first completes.
 *
 * @tag repos
 * @path repos/:owner/:repo/pages/builds
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepo(connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<postByOwnerAndRepo.Output>;
export declare namespace postByOwnerAndRepo {
    type Headers = IApiReposPagesBuilds.PostHeader;
    type Output = page_minus_build_minus_status;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/pages/builds";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => page_minus_build_minus_status;
    const simulate: (connection: IConnection<postByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get GitHub Pages build.
 * Gets information about a GitHub Pages build.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/pages/builds/:build_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndBuild_id(connection: IConnection<getByOwnerAndRepoAndBuild_id.Headers>, owner: string, repo: string, build_id: number & tags.Type<"int32">): Promise<getByOwnerAndRepoAndBuild_id.Output>;
export declare namespace getByOwnerAndRepoAndBuild_id {
    type Headers = IApiReposPagesBuilds.GetHeader;
    type Output = page_minus_build;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/pages/builds/:build_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, build_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => page_minus_build;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndBuild_id.Headers>, owner: string, repo: string, build_id: number & tags.Type<"int32">) => Output;
}
