import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPagesHealth } from "../../../../structures/IApiReposPagesHealth";
import { pages_minus_health_minus_check } from "../../../../structures/pages_minus_health_minus_check";
/**
 * Get a DNS health check for GitHub Pages.
 * Gets a health check of the DNS settings for the `CNAME` record configured for a repository's GitHub Pages.
 *
 * The first request to this endpoint returns a `202 Accepted` status and starts an asynchronous background task to get the results for the domain. After the background task completes, subsequent requests to this endpoint return a `200 OK` status with the health check results in the response.
 *
 * The authenticated user must be a repository administrator, maintainer, or have the 'manage GitHub Pages settings' permission to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/pages/health
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposPagesHealth.GetHeader;
    type Output = pages_minus_health_minus_check;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/pages/health";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => pages_minus_health_minus_check;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
