import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPropertiesValues } from "../../../../structures/IApiReposPropertiesValues";
import { body } from "../../../../structures/body";
import { custom_minus_property_minus_value } from "../../../../structures/custom_minus_property_minus_value";
/**
 * Get all custom property values for a repository.
 * Gets all custom property values that are set for a repository.
 * Users with read access to the repository can use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/properties/values
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposPropertiesValues.GetHeader;
    type Output = custom_minus_property_minus_value[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/properties/values";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => custom_minus_property_minus_value[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Create or update custom property values for a repository.
 * Create new or update existing custom property values for a repository.
 * Using a value of `null` for a custom property will remove or 'unset' the property value from the repository.
 *
 * Repository admins and other users with the repository-level "edit custom property values" fine-grained permission can use this endpoint.
 *
 * @tag repos
 * @path repos/:owner/:repo/properties/values
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepo(connection: IConnection<patchByOwnerAndRepo.Headers>, owner: string, repo: string, body: patchByOwnerAndRepo.Input): Promise<void>;
export declare namespace patchByOwnerAndRepo {
    type Headers = IApiReposPropertiesValues.PatchHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/properties/values";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<patchByOwnerAndRepo.Headers>, owner: string, repo: string, body: patchByOwnerAndRepo.Input) => void;
}
