import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposPullsReviewsDismissals } from "../../../../../structures/IApiReposPullsReviewsDismissals";
import { body } from "../../../../../structures/body";
import { pull_minus_request_minus_review } from "../../../../../structures/pull_minus_request_minus_review";
/**
 * Dismiss a review for a pull request.
 * Dismisses a specified review on a pull request.
 *
 * > [!NOTE]
 * > To dismiss a pull request review on a [protected branch](https://docs.github.com/rest/branches/branch-protection), you must be a repository administrator or be included in the list of people or teams who can dismiss pull request reviews.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github-commitcomment.raw+json`**: Returns the raw markdown body. Response will include `body`. This is the default if you do not pass any specific media type.
 * - **`application/vnd.github-commitcomment.text+json`**: Returns a text only representation of the markdown body. Response will include `body_text`.
 * - **`application/vnd.github-commitcomment.html+json`**: Returns HTML rendered from the body's markdown. Response will include `body_html`.
 * - **`application/vnd.github-commitcomment.full+json`**: Returns raw, text, and HTML representations. Response will include `body`, `body_text`, and `body_html`.
 *
 * @tag pulls
 * @path repos/:owner/:repo/pulls/:pull_number/reviews/:review_id/dismissals
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepoAndPull_numberAndReview_id(connection: IConnection<putByOwnerAndRepoAndPull_numberAndReview_id.Headers>, owner: string, repo: string, pull_number: string, review_id: string, body: putByOwnerAndRepoAndPull_numberAndReview_id.Input): Promise<putByOwnerAndRepoAndPull_numberAndReview_id.Output>;
export declare namespace putByOwnerAndRepoAndPull_numberAndReview_id {
    type Headers = IApiReposPullsReviewsDismissals.PutHeader;
    type Input = body;
    type Output = pull_minus_request_minus_review;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/pulls/:pull_number/reviews/:review_id/dismissals";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, pull_number: string, review_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => pull_minus_request_minus_review;
    const simulate: (connection: IConnection<putByOwnerAndRepoAndPull_numberAndReview_id.Headers>, owner: string, repo: string, pull_number: string, review_id: string, body: putByOwnerAndRepoAndPull_numberAndReview_id.Input) => Output;
}
