import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposReadme } from "../../../structures/IApiReposReadme";
import { content_minus_file } from "../../../structures/content_minus_file";
/**
 * Get a repository README.
 * Gets the preferred README for a repository.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw file contents. This is the default if you do not specify a media type.
 * - **`application/vnd.github.html+json`**: Returns the README in HTML. Markup languages are rendered to HTML using GitHub's open-source [Markup library](https://github.com/github/markup).
 *
 * @tag repos
 * @path repos/:owner/:repo/readme
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposReadme.GetHeader;
    type Query = IApiReposReadme.GetQuery;
    type Output = content_minus_file;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/readme";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, query: getByOwnerAndRepo.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => content_minus_file;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string, query: getByOwnerAndRepo.Query) => Output;
}
/**
 * Get a repository README for a directory.
 * Gets the README from a repository directory.
 *
 * This endpoint supports the following custom media types. For more information, see "[Media types](https://docs.github.com/rest/using-the-rest-api/getting-started-with-the-rest-api#media-types)."
 *
 * - **`application/vnd.github.raw+json`**: Returns the raw file contents. This is the default if you do not specify a media type.
 * - **`application/vnd.github.html+json`**: Returns the README in HTML. Markup languages are rendered to HTML using GitHub's open-source [Markup library](https://github.com/github/markup).
 *
 * @param dir The alternate path to look for a README file
 * @tag repos
 * @path repos/:owner/:repo/readme/:dir
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndDir(connection: IConnection<getByOwnerAndRepoAndDir.Headers>, owner: string, repo: string, dir: string, query: getByOwnerAndRepoAndDir.Query): Promise<getByOwnerAndRepoAndDir.Output>;
export declare namespace getByOwnerAndRepoAndDir {
    type Headers = IApiReposReadme.GetHeader;
    type Query = IApiReposReadme.GetQuery;
    type Output = content_minus_file;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/readme/:dir";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, dir: string, query: getByOwnerAndRepoAndDir.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => content_minus_file;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndDir.Headers>, owner: string, repo: string, dir: string, query: getByOwnerAndRepoAndDir.Query) => Output;
}
