import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposReleasesReactions } from "../../../../structures/IApiReposReleasesReactions";
import { body } from "../../../../structures/body";
import { reaction } from "../../../../structures/reaction";
/**
 * List reactions for a release.
 * List the reactions to a [release](https://docs.github.com/rest/releases/releases#get-a-release).
 *
 * @tag reactions
 * @path repos/:owner/:repo/releases/:release_id/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndRelease_id(connection: IConnection<getByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string, query: getByOwnerAndRepoAndRelease_id.Query): Promise<getByOwnerAndRepoAndRelease_id.Output>;
export declare namespace getByOwnerAndRepoAndRelease_id {
    type Headers = IApiReposReleasesReactions.GetHeader;
    type Query = IApiReposReleasesReactions.GetQuery;
    type Output = reaction[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/releases/:release_id/reactions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string, query: getByOwnerAndRepoAndRelease_id.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction[];
    const simulate: (connection: IConnection<getByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string, query: getByOwnerAndRepoAndRelease_id.Query) => Output;
}
/**
 * Create reaction for a release.
 * Create a reaction to a [release](https://docs.github.com/rest/releases/releases#get-a-release). A response with a `Status: 200 OK` means that you already added the reaction type to this release.
 *
 * @tag reactions
 * @path repos/:owner/:repo/releases/:release_id/reactions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndRelease_id(connection: IConnection<postByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string, body: postByOwnerAndRepoAndRelease_id.Input): Promise<postByOwnerAndRepoAndRelease_id.Output>;
export declare namespace postByOwnerAndRepoAndRelease_id {
    type Headers = IApiReposReleasesReactions.PostHeader;
    type Input = body;
    type Output = reaction;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/releases/:release_id/reactions";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => reaction;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndRelease_id.Headers>, owner: string, repo: string, release_id: string, body: postByOwnerAndRepoAndRelease_id.Input) => Output;
}
/**
 * Delete a release reaction.
 * > [!NOTE]
 * > You can also specify a repository by `repository_id` using the route `DELETE delete /repositories/:repository_id/releases/:release_id/reactions/:reaction_id`.
 *
 * Delete a reaction to a [release](https://docs.github.com/rest/releases/releases#get-a-release).
 *
 * @tag reactions
 * @path repos/:owner/:repo/releases/:release_id/reactions/:reaction_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepoAndRelease_idAndReaction_id(connection: IConnection<eraseByOwnerAndRepoAndRelease_idAndReaction_id.Headers>, owner: string, repo: string, release_id: string, reaction_id: string): Promise<void>;
export declare namespace eraseByOwnerAndRepoAndRelease_idAndReaction_id {
    type Headers = IApiReposReleasesReactions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/releases/:release_id/reactions/:reaction_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, release_id: string, reaction_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepoAndRelease_idAndReaction_id.Headers>, owner: string, repo: string, release_id: string, reaction_id: string) => void;
}
