import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposSecretScanningAlerts } from "../../../../structures/IApiReposSecretScanningAlerts";
import { body } from "../../../../structures/body";
import { secret_minus_scanning_minus_alert } from "../../../../structures/secret_minus_scanning_minus_alert";
export * as locations from "./locations";
/**
 * List secret scanning alerts for a repository.
 * Lists secret scanning alerts for an eligible repository, from newest to oldest.
 *
 * The authenticated user must be an administrator for the repository or for the organization that owns the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` or `security_events` scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the `public_repo` scope instead.
 *
 * @tag secret-scanning
 * @path repos/:owner/:repo/secret-scanning/alerts
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposSecretScanningAlerts.GetHeader;
    type Output = secret_minus_scanning_minus_alert[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/secret-scanning/alerts";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => secret_minus_scanning_minus_alert[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Get a secret scanning alert.
 * Gets a single secret scanning alert detected in an eligible repository.
 *
 * The authenticated user must be an administrator for the repository or for the organization that owns the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` or `security_events` scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the `public_repo` scope instead.
 *
 * @tag secret-scanning
 * @path repos/:owner/:repo/secret-scanning/alerts/:alert_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepoAndAlert_number(connection: IConnection<getByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string): Promise<getByOwnerAndRepoAndAlert_number.Output>;
export declare namespace getByOwnerAndRepoAndAlert_number {
    type Headers = IApiReposSecretScanningAlerts.GetHeader;
    type Output = secret_minus_scanning_minus_alert;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/secret-scanning/alerts/:alert_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, alert_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => secret_minus_scanning_minus_alert;
    const simulate: (connection: IConnection<getByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string) => Output;
}
/**
 * Update a secret scanning alert.
 * Updates the status of a secret scanning alert in an eligible repository.
 *
 * The authenticated user must be an administrator for the repository or for the organization that owns the repository to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` or `security_events` scope to use this endpoint. If this endpoint is only used with public repositories, the token can use the `public_repo` scope instead.
 *
 * @tag secret-scanning
 * @path repos/:owner/:repo/secret-scanning/alerts/:alert_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOwnerAndRepoAndAlert_number(connection: IConnection<patchByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string, body: patchByOwnerAndRepoAndAlert_number.Input): Promise<patchByOwnerAndRepoAndAlert_number.Output>;
export declare namespace patchByOwnerAndRepoAndAlert_number {
    type Headers = IApiReposSecretScanningAlerts.PatchHeader;
    type Input = body;
    type Output = secret_minus_scanning_minus_alert;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/repos/:owner/:repo/secret-scanning/alerts/:alert_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, alert_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => secret_minus_scanning_minus_alert;
    const simulate: (connection: IConnection<patchByOwnerAndRepoAndAlert_number.Headers>, owner: string, repo: string, alert_number: string, body: patchByOwnerAndRepoAndAlert_number.Input) => Output;
}
