import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposSecurityAdvisoriesCve } from "../../../../structures/IApiReposSecurityAdvisoriesCve";
/**
 * Request a CVE for a repository security advisory.
 * If you want a CVE identification number for the security vulnerability in your project, and don't already have one, you can request a CVE identification number from GitHub. For more information see "[Requesting a CVE identification number](https://docs.github.com/code-security/security-advisories/repository-security-advisories/publishing-a-repository-security-advisory#requesting-a-cve-identification-number-optional)."
 *
 * You may request a CVE for public repositories, but cannot do so for private repositories.
 *
 * In order to request a CVE for a repository security advisory, the authenticated user must be a security manager or administrator of that repository.
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` or `repository_advisories:write` scope to use this endpoint.
 *
 * @tag security-advisories
 * @path repos/:owner/:repo/security-advisories/:ghsa_id/cve
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByOwnerAndRepoAndGhsa_id(connection: IConnection<postByOwnerAndRepoAndGhsa_id.Headers>, owner: string, repo: string, ghsa_id: string): Promise<void>;
export declare namespace postByOwnerAndRepoAndGhsa_id {
    type Headers = IApiReposSecurityAdvisoriesCve.PostHeader;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/repos/:owner/:repo/security-advisories/:ghsa_id/cve";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string, ghsa_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByOwnerAndRepoAndGhsa_id.Headers>, owner: string, repo: string, ghsa_id: string) => void;
}
