import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposStatsContributors } from "../../../../structures/IApiReposStatsContributors";
import { contributor_minus_activity } from "../../../../structures/contributor_minus_activity";
/**
 * Get all contributor commit activity.
 *
 * Returns the `total` number of commits authored by the contributor. In addition, the response includes a Weekly Hash (`weeks` array) with the following information:
 *
 * *   `w` - Start of the week, given as a [Unix timestamp](https://en.wikipedia.org/wiki/Unix_time).
 * *   `a` - Number of additions
 * *   `d` - Number of deletions
 * *   `c` - Number of commits
 *
 * > [!NOTE]
 * > This endpoint will return `0` values for all addition and deletion counts in repositories with 10,000 or more commits.
 *
 * @tag repos
 * @path repos/:owner/:repo/stats/contributors
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposStatsContributors.GetHeader;
    type Output = contributor_minus_activity[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/stats/contributors";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => contributor_minus_activity[];
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
