import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposSubscription } from "../../../structures/IApiReposSubscription";
import { body } from "../../../structures/body";
import { repository_minus_subscription } from "../../../structures/repository_minus_subscription";
/**
 * Get a repository subscription.
 * Gets information about whether the authenticated user is subscribed to the repository.
 *
 * @tag activity
 * @path repos/:owner/:repo/subscription
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<getByOwnerAndRepo.Output>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposSubscription.GetHeader;
    type Output = repository_minus_subscription;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/subscription";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => repository_minus_subscription;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => Output;
}
/**
 * Set a repository subscription.
 * If you would like to watch a repository, set `subscribed` to `true`. If you would like to ignore notifications made within a repository, set `ignored` to `true`. If you would like to stop watching a repository, [delete the repository's subscription](https://docs.github.com/rest/activity/watching#delete-a-repository-subscription) completely.
 *
 * @tag activity
 * @path repos/:owner/:repo/subscription
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input): Promise<putByOwnerAndRepo.Output>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposSubscription.PutHeader;
    type Input = body;
    type Output = repository_minus_subscription;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/subscription";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => repository_minus_subscription;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string, body: putByOwnerAndRepo.Input) => Output;
}
/**
 * Delete a repository subscription.
 * This endpoint should only be used to stop watching a repository. To control whether or not you wish to receive notifications from a repository, [set the repository's subscription manually](https://docs.github.com/rest/activity/watching#set-a-repository-subscription).
 *
 * @tag activity
 * @path repos/:owner/:repo/subscription
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepo(connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace eraseByOwnerAndRepo {
    type Headers = IApiReposSubscription.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/subscription";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
