import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiSearchRepositories } from "../../../structures/IApiSearchRepositories";
import { response } from "../../../structures/response";
/**
 * Search repositories.
 * Find repositories via various criteria. This method returns up to 100 results [per page](https://docs.github.com/rest/guides/using-pagination-in-the-rest-api).
 *
 * When searching for repositories, you can get text match metadata for the **name** and **description** fields when you pass the `text-match` media type. For more details about how to receive highlighted search results, see [Text match metadata](https://docs.github.com/rest/search/search#text-match-metadata).
 *
 * For example, if you want to search for popular Tetris repositories written in assembly code, your query might look like this:
 *
 * `q=tetris+language:assembly&sort=stars&order=desc`
 *
 * This query searches for repositories with the word `tetris` in the name, the description, or the README. The results are limited to repositories where the primary language is assembly. The results are sorted by stars in descending order, so that the most popular repositories appear first in the search results.
 *
 * @tag search
 * @path search/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiSearchRepositories.GetHeader;
    type Query = IApiSearchRepositories.GetQuery;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/search/repositories";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
