import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiTeamsDiscussionsComments } from "../../../../structures/IApiTeamsDiscussionsComments";
import { body } from "../../../../structures/body";
import { team_minus_discussion_minus_comment } from "../../../../structures/team_minus_discussion_minus_comment";
export * as reactions from "./reactions";
/**
 * List discussion comments (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [List discussion comments](https://docs.github.com/rest/teams/discussion-comments#list-discussion-comments) endpoint.
 *
 * List all comments on a team discussion.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByTeam_idAndDiscussion_number(connection: IConnection<getByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string): Promise<getByTeam_idAndDiscussion_number.Output>;
export declare namespace getByTeam_idAndDiscussion_number {
    type Headers = IApiTeamsDiscussionsComments.GetHeader;
    type Output = team_minus_discussion_minus_comment[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/teams/:team_id/discussions/:discussion_number/comments";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment[];
    const simulate: (connection: IConnection<getByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string) => Output;
}
/**
 * Create a discussion comment (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Create a discussion comment](https://docs.github.com/rest/teams/discussion-comments#create-a-discussion-comment) endpoint.
 *
 * Creates a new comment on a team discussion.
 *
 * This endpoint triggers [notifications](https://docs.github.com/github/managing-subscriptions-and-notifications-on-github/about-notifications). Creating content too quickly using this endpoint may result in secondary rate limiting. For more information, see "[Rate limits for the API](https://docs.github.com/rest/using-the-rest-api/rate-limits-for-the-rest-api#about-secondary-rate-limits)" and "[Best practices for using the REST API](https://docs.github.com/rest/guides/best-practices-for-using-the-rest-api)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number/comments
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByTeam_idAndDiscussion_number(connection: IConnection<postByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string, body: postByTeam_idAndDiscussion_number.Input): Promise<postByTeam_idAndDiscussion_number.Output>;
export declare namespace postByTeam_idAndDiscussion_number {
    type Headers = IApiTeamsDiscussionsComments.PostHeader;
    type Input = body;
    type Output = team_minus_discussion_minus_comment;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/teams/:team_id/discussions/:discussion_number/comments";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment;
    const simulate: (connection: IConnection<postByTeam_idAndDiscussion_number.Headers>, team_id: string, discussion_number: string, body: postByTeam_idAndDiscussion_number.Input) => Output;
}
/**
 * Get a discussion comment (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Get a discussion comment](https://docs.github.com/rest/teams/discussion-comments#get-a-discussion-comment) endpoint.
 *
 * Get a specific comment on a team discussion.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number/comments/:comment_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByTeam_idAndDiscussion_numberAndComment_number(connection: IConnection<getByTeam_idAndDiscussion_numberAndComment_number.Headers>, team_id: string, discussion_number: string, comment_number: string): Promise<getByTeam_idAndDiscussion_numberAndComment_number.Output>;
export declare namespace getByTeam_idAndDiscussion_numberAndComment_number {
    type Headers = IApiTeamsDiscussionsComments.GetHeader;
    type Output = team_minus_discussion_minus_comment;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/teams/:team_id/discussions/:discussion_number/comments/:comment_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment;
    const simulate: (connection: IConnection<getByTeam_idAndDiscussion_numberAndComment_number.Headers>, team_id: string, discussion_number: string, comment_number: string) => Output;
}
/**
 * Update a discussion comment (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Update a discussion comment](https://docs.github.com/rest/teams/discussion-comments#update-a-discussion-comment) endpoint.
 *
 * Edits the body text of a discussion comment.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number/comments/:comment_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByTeam_idAndDiscussion_numberAndComment_number(connection: IConnection<patchByTeam_idAndDiscussion_numberAndComment_number.Headers>, team_id: string, discussion_number: string, comment_number: string, body: patchByTeam_idAndDiscussion_numberAndComment_number.Input): Promise<patchByTeam_idAndDiscussion_numberAndComment_number.Output>;
export declare namespace patchByTeam_idAndDiscussion_numberAndComment_number {
    type Headers = IApiTeamsDiscussionsComments.PatchHeader;
    type Input = body;
    type Output = team_minus_discussion_minus_comment;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/teams/:team_id/discussions/:discussion_number/comments/:comment_number";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => team_minus_discussion_minus_comment;
    const simulate: (connection: IConnection<patchByTeam_idAndDiscussion_numberAndComment_number.Headers>, team_id: string, discussion_number: string, comment_number: string, body: patchByTeam_idAndDiscussion_numberAndComment_number.Input) => Output;
}
/**
 * Delete a discussion comment (Legacy).
 * > [!WARNING]
 * > **Deprecation notice:** This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new [Delete a discussion comment](https://docs.github.com/rest/teams/discussion-comments#delete-a-discussion-comment) endpoint.
 *
 * Deletes a comment on a team discussion.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:discussion` scope to use this endpoint.
 *
 * @tag teams
 * @deprecated
 * @path teams/:team_id/discussions/:discussion_number/comments/:comment_number
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByTeam_idAndDiscussion_numberAndComment_number(connection: IConnection<eraseByTeam_idAndDiscussion_numberAndComment_number.Headers>, team_id: string, discussion_number: string, comment_number: string): Promise<void>;
export declare namespace eraseByTeam_idAndDiscussion_numberAndComment_number {
    type Headers = IApiTeamsDiscussionsComments.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/teams/:team_id/discussions/:discussion_number/comments/:comment_number";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (team_id: string, discussion_number: string, comment_number: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByTeam_idAndDiscussion_numberAndComment_number.Headers>, team_id: string, discussion_number: string, comment_number: string) => void;
}
