import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserCodespacesExports } from "../../../../structures/IApiUserCodespacesExports";
import { codespace_minus_export_minus_details } from "../../../../structures/codespace_minus_export_minus_details";
/**
 * Export a codespace for the authenticated user.
 * Triggers an export of the specified codespace and returns a URL and ID where the status of the export can be monitored.
 *
 * If changes cannot be pushed to the codespace's repository, they will be pushed to a new or previously-existing fork instead.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/:codespace_name/exports
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function postByCodespace_name(connection: IConnection<postByCodespace_name.Headers>, codespace_name: string): Promise<void>;
export declare namespace postByCodespace_name {
    type Headers = IApiUserCodespacesExports.PostHeader;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/codespaces/:codespace_name/exports";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (codespace_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<postByCodespace_name.Headers>, codespace_name: string) => void;
}
/**
 * Get details about a codespace export.
 * Gets information about an export of a codespace.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/:codespace_name/exports/:export_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByCodespace_nameAndExport_id(connection: IConnection<getByCodespace_nameAndExport_id.Headers>, codespace_name: string, export_id: string): Promise<getByCodespace_nameAndExport_id.Output>;
export declare namespace getByCodespace_nameAndExport_id {
    type Headers = IApiUserCodespacesExports.GetHeader;
    type Output = codespace_minus_export_minus_details;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/codespaces/:codespace_name/exports/:export_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (codespace_name: string, export_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => codespace_minus_export_minus_details;
    const simulate: (connection: IConnection<getByCodespace_nameAndExport_id.Headers>, codespace_name: string, export_id: string) => Output;
}
