import { IConnection } from "@nestia/fetcher";
import typia, { tags } from "typia";
import { IApiUserCodespacesSecretsRepositories } from "../../../../../structures/IApiUserCodespacesSecretsRepositories";
import { body } from "../../../../../structures/body";
import { response } from "../../../../../structures/response";
/**
 * List selected repositories for a user secret.
 * List the repositories that have been granted the ability to use a user's development environment secret.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getBySecret_name(connection: IConnection<getBySecret_name.Headers>, secret_name: string): Promise<getBySecret_name.Output>;
export declare namespace getBySecret_name {
    type Headers = IApiUserCodespacesSecretsRepositories.GetHeader;
    type Output = response;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/codespaces/secrets/:secret_name/repositories";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => response;
    const simulate: (connection: IConnection<getBySecret_name.Headers>, secret_name: string) => Output;
}
/**
 * Set selected repositories for a user secret.
 * Select the repositories that will use a user's development environment secret.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name/repositories
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putBySecret_name(connection: IConnection<putBySecret_name.Headers>, secret_name: string, body: putBySecret_name.Input): Promise<void>;
export declare namespace putBySecret_name {
    type Headers = IApiUserCodespacesSecretsRepositories.PutHeader;
    type Input = body;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/user/codespaces/secrets/:secret_name/repositories";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putBySecret_name.Headers>, secret_name: string, body: putBySecret_name.Input) => void;
}
/**
 * Add a selected repository to a user secret.
 * Adds a repository to the selected repositories for a user's development environment secret.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putBySecret_nameAndRepository_id(connection: IConnection<putBySecret_nameAndRepository_id.Headers>, secret_name: string, repository_id: number & tags.Type<"int32">): Promise<void>;
export declare namespace putBySecret_nameAndRepository_id {
    type Headers = IApiUserCodespacesSecretsRepositories.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/user/codespaces/secrets/:secret_name/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string, repository_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putBySecret_nameAndRepository_id.Headers>, secret_name: string, repository_id: number & tags.Type<"int32">) => void;
}
/**
 * Remove a selected repository from a user secret.
 * Removes a repository from the selected repositories for a user's development environment secret.
 *
 * The authenticated user must have Codespaces access to use this endpoint.
 *
 * OAuth app tokens and personal access tokens (classic) need the `codespace` or `codespace:secrets` scope to use this endpoint.
 *
 * @tag codespaces
 * @path user/codespaces/secrets/:secret_name/repositories/:repository_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseBySecret_nameAndRepository_id(connection: IConnection<eraseBySecret_nameAndRepository_id.Headers>, secret_name: string, repository_id: number & tags.Type<"int32">): Promise<void>;
export declare namespace eraseBySecret_nameAndRepository_id {
    type Headers = IApiUserCodespacesSecretsRepositories.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/codespaces/secrets/:secret_name/repositories/:repository_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (secret_name: string, repository_id: number & tags.Type<"int32">) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseBySecret_nameAndRepository_id.Headers>, secret_name: string, repository_id: number & tags.Type<"int32">) => void;
}
