import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserGpgKeys } from "../../../structures/IApiUserGpgKeys";
import { body } from "../../../structures/body";
import { gpg_minus_key } from "../../../structures/gpg_minus_key";
/**
 * List GPG keys for the authenticated user.
 * Lists the current user's GPG keys.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:gpg_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/gpg_keys
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserGpgKeys.GetHeader;
    type Output = gpg_minus_key[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/gpg_keys";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gpg_minus_key[];
    const simulate: (connection: IConnection<get.Headers>) => Output;
}
/**
 * Create a GPG key for the authenticated user.
 * Adds a GPG key to the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `write:gpg_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/gpg_keys
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = gpg_minus_key;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/gpg_keys";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gpg_minus_key;
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
/**
 * Get a GPG key for the authenticated user.
 * View extended details for a single GPG key.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:gpg_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/gpg_keys/:gpg_key_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByGpg_key_id(connection: IConnection<getByGpg_key_id.Headers>, gpg_key_id: string): Promise<getByGpg_key_id.Output>;
export declare namespace getByGpg_key_id {
    type Headers = IApiUserGpgKeys.GetHeader;
    type Output = gpg_minus_key;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/gpg_keys/:gpg_key_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gpg_key_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => gpg_minus_key;
    const simulate: (connection: IConnection<getByGpg_key_id.Headers>, gpg_key_id: string) => Output;
}
/**
 * Delete a GPG key for the authenticated user.
 * Removes a GPG key from the authenticated user's GitHub account.
 *
 * OAuth app tokens and personal access tokens (classic) need the `admin:gpg_key` scope to use this endpoint.
 *
 * @tag users
 * @path user/gpg_keys/:gpg_key_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByGpg_key_id(connection: IConnection<eraseByGpg_key_id.Headers>, gpg_key_id: string): Promise<void>;
export declare namespace eraseByGpg_key_id {
    type Headers = IApiUserGpgKeys.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/user/gpg_keys/:gpg_key_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (gpg_key_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByGpg_key_id.Headers>, gpg_key_id: string) => void;
}
