import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserMembershipsOrgs } from "../../../../structures/IApiUserMembershipsOrgs";
import { body } from "../../../../structures/body";
import { org_minus_membership } from "../../../../structures/org_minus_membership";
/**
 * List organization memberships for the authenticated user.
 * Lists all of the authenticated user's organization memberships.
 *
 * @tag orgs
 * @path user/memberships/orgs
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserMembershipsOrgs.GetHeader;
    type Query = IApiUserMembershipsOrgs.GetQuery;
    type Output = org_minus_membership[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/memberships/orgs";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => org_minus_membership[];
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
/**
 * Get an organization membership for the authenticated user.
 * If the authenticated user is an active or pending member of the organization, this endpoint will return the user's membership. If the authenticated user is not affiliated with the organization, a `404` is returned. This endpoint will return a `403` if the request is made by a GitHub App that is blocked by the organization.
 *
 * @tag orgs
 * @path user/memberships/orgs/:org
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOrg(connection: IConnection<getByOrg.Headers>, org: string): Promise<getByOrg.Output>;
export declare namespace getByOrg {
    type Headers = IApiUserMembershipsOrgs.GetHeader;
    type Output = org_minus_membership;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/memberships/orgs/:org";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => org_minus_membership;
    const simulate: (connection: IConnection<getByOrg.Headers>, org: string) => Output;
}
/**
 * Update an organization membership for the authenticated user.
 * Converts the authenticated user to an active member of the organization, if that user has a pending invitation from the organization.
 *
 * @tag orgs
 * @path user/memberships/orgs/:org
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function patchByOrg(connection: IConnection<patchByOrg.Headers>, org: string, body: patchByOrg.Input): Promise<patchByOrg.Output>;
export declare namespace patchByOrg {
    type Headers = IApiUserMembershipsOrgs.PatchHeader;
    type Input = body;
    type Output = org_minus_membership;
    const METADATA: {
        readonly method: "PATCH";
        readonly path: "/user/memberships/orgs/:org";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (org: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => org_minus_membership;
    const simulate: (connection: IConnection<patchByOrg.Headers>, org: string, body: patchByOrg.Input) => Output;
}
