import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUserRepos } from "../../../structures/IApiUserRepos";
import { body } from "../../../structures/body";
import { full_minus_repository } from "../../../structures/full_minus_repository";
import { repository } from "../../../structures/repository";
/**
 * List repositories for the authenticated user.
 * Lists repositories that the authenticated user has explicit permission (`:read`, `:write`, or `:admin`) to access.
 *
 * The authenticated user has explicit permission to access repositories they own, repositories where they are a collaborator, and repositories that they can access through an organization membership.
 *
 * @tag repos
 * @path user/repos
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function get(connection: IConnection<get.Headers>, query: get.Query): Promise<get.Output>;
export declare namespace get {
    type Headers = IApiUserRepos.GetHeader;
    type Query = IApiUserRepos.GetQuery;
    type Output = repository[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/user/repos";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (query: get.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => repository[];
    const simulate: (connection: IConnection<get.Headers>, query: get.Query) => Output;
}
/**
 * Create a repository for the authenticated user.
 * Creates a new repository for the authenticated user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `public_repo` or `repo` scope to create a public repository, and `repo` scope to create a private repository.
 *
 * @tag repos
 * @path user/repos
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function post(connection: IConnection, body: post.Input): Promise<post.Output>;
export declare namespace post {
    type Input = body;
    type Output = full_minus_repository;
    const METADATA: {
        readonly method: "POST";
        readonly path: "/user/repos";
        readonly request: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: () => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => full_minus_repository;
    const simulate: (connection: IConnection, body: post.Input) => Output;
}
