import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUsersHovercard } from "../../../structures/IApiUsersHovercard";
import { hovercard } from "../../../structures/hovercard";
/**
 * Get contextual information for a user.
 * Provides hovercard information. You can find out more about someone in relation to their pull requests, issues, repositories, and organizations.
 *
 * The `subject_type` and `subject_id` parameters provide context for the person's hovercard, which returns more information than without the parameters. For example, if you wanted to find out more about `octocat` who owns the `Spoon-Knife` repository, you would use a `subject_type` value of `repository` and a `subject_id` value of `1300192` (the ID of the `Spoon-Knife` repository).
 *
 * OAuth app tokens and personal access tokens (classic) need the `repo` scope to use this endpoint.
 *
 * @tag users
 * @path users/:username/hovercard
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByUsername(connection: IConnection<getByUsername.Headers>, username: string, query: getByUsername.Query): Promise<getByUsername.Output>;
export declare namespace getByUsername {
    type Headers = IApiUsersHovercard.GetHeader;
    type Query = IApiUsersHovercard.GetQuery;
    type Output = hovercard;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/users/:username/hovercard";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, query: getByUsername.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => hovercard;
    const simulate: (connection: IConnection<getByUsername.Headers>, username: string, query: getByUsername.Query) => Output;
}
