import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUsersPackages } from "../../../structures/IApiUsersPackages";
import { packages } from "../../../structures/package";
export * as restore from "./restore";
export * as versions from "./versions";
/**
 * List packages for a user.
 * Lists all packages in a user's namespace for which the requesting user has access.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path users/:username/packages
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByUsername(connection: IConnection<getByUsername.Headers>, username: string, query: getByUsername.Query): Promise<getByUsername.Output>;
export declare namespace getByUsername {
    type Headers = IApiUsersPackages.GetHeader;
    type Query = IApiUsersPackages.GetQuery;
    type Output = packages[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/users/:username/packages";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, query: getByUsername.Query) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => packages[];
    const simulate: (connection: IConnection<getByUsername.Headers>, username: string, query: getByUsername.Query) => Output;
}
/**
 * Get a package for a user.
 * Gets a specific package metadata for a public package owned by a user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path users/:username/packages/:package_type/:package_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByUsernameAndPackage_typeAndPackage_name(connection: IConnection<getByUsernameAndPackage_typeAndPackage_name.Headers>, username: string, package_type: string, package_name: string): Promise<getByUsernameAndPackage_typeAndPackage_name.Output>;
export declare namespace getByUsernameAndPackage_typeAndPackage_name {
    type Headers = IApiUsersPackages.GetHeader;
    type Output = packages;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/users/:username/packages/:package_type/:package_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => packages;
    const simulate: (connection: IConnection<getByUsernameAndPackage_typeAndPackage_name.Headers>, username: string, package_type: string, package_name: string) => Output;
}
/**
 * Delete a package for a user.
 * Deletes an entire package for a user. You cannot delete a public package if any version of the package has more than 5,000 downloads. In this scenario, contact GitHub support for further assistance.
 *
 * If the `package_type` belongs to a GitHub Packages registry that supports granular permissions, the authenticated user must have admin permissions to the package. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#granular-permissions-for-userorganization-scoped-packages)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` and `delete:packages` scopes to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path users/:username/packages/:package_type/:package_name
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByUsernameAndPackage_typeAndPackage_name(connection: IConnection<eraseByUsernameAndPackage_typeAndPackage_name.Headers>, username: string, package_type: string, package_name: string): Promise<void>;
export declare namespace eraseByUsernameAndPackage_typeAndPackage_name {
    type Headers = IApiUsersPackages.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/users/:username/packages/:package_type/:package_name";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByUsernameAndPackage_typeAndPackage_name.Headers>, username: string, package_type: string, package_name: string) => void;
}
