import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiUsersPackagesVersions } from "../../../../structures/IApiUsersPackagesVersions";
import { package_minus_version } from "../../../../structures/package_minus_version";
export * as restore from "./restore";
/**
 * List package versions for a package owned by a user.
 * Lists package versions for a public package owned by a specified user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path users/:username/packages/:package_type/:package_name/versions
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByUsernameAndPackage_typeAndPackage_name(connection: IConnection<getByUsernameAndPackage_typeAndPackage_name.Headers>, username: string, package_type: string, package_name: string): Promise<getByUsernameAndPackage_typeAndPackage_name.Output>;
export declare namespace getByUsernameAndPackage_typeAndPackage_name {
    type Headers = IApiUsersPackagesVersions.GetHeader;
    type Output = package_minus_version[];
    const METADATA: {
        readonly method: "GET";
        readonly path: "/users/:username/packages/:package_type/:package_name/versions";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, package_type: string, package_name: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => package_minus_version[];
    const simulate: (connection: IConnection<getByUsernameAndPackage_typeAndPackage_name.Headers>, username: string, package_type: string, package_name: string) => Output;
}
/**
 * Get a package version for a user.
 * Gets a specific package version for a public package owned by a specified user.
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` scope to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path users/:username/packages/:package_type/:package_name/versions/:package_version_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id(connection: IConnection<getByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id.Headers>, username: string, package_type: string, package_name: string, package_version_id: string): Promise<getByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id.Output>;
export declare namespace getByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id {
    type Headers = IApiUsersPackagesVersions.GetHeader;
    type Output = package_minus_version;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/users/:username/packages/:package_type/:package_name/versions/:package_version_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, package_type: string, package_name: string, package_version_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => package_minus_version;
    const simulate: (connection: IConnection<getByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id.Headers>, username: string, package_type: string, package_name: string, package_version_id: string) => Output;
}
/**
 * Delete package version for a user.
 * Deletes a specific package version for a user. If the package is public and the package version has more than 5,000 downloads, you cannot delete the package version. In this scenario, contact GitHub support for further assistance.
 *
 * If the `package_type` belongs to a GitHub Packages registry that supports granular permissions, the authenticated user must have admin permissions to the package. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#granular-permissions-for-userorganization-scoped-packages)."
 *
 * OAuth app tokens and personal access tokens (classic) need the `read:packages` and `delete:packages` scopes to use this endpoint. If the `package_type` belongs to a GitHub Packages registry that only supports repository-scoped permissions, the `repo` scope is also required. For the list of these registries, see "[About permissions for GitHub Packages](https://docs.github.com/packages/learn-github-packages/about-permissions-for-github-packages#permissions-for-repository-scoped-packages)."
 *
 * @tag packages
 * @path users/:username/packages/:package_type/:package_name/versions/:package_version_id
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id(connection: IConnection<eraseByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id.Headers>, username: string, package_type: string, package_name: string, package_version_id: string): Promise<void>;
export declare namespace eraseByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id {
    type Headers = IApiUsersPackagesVersions.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/users/:username/packages/:package_type/:package_name/versions/:package_version_id";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (username: string, package_type: string, package_name: string, package_version_id: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByUsernameAndPackage_typeAndPackage_nameAndPackage_version_id.Headers>, username: string, package_type: string, package_name: string, package_version_id: string) => void;
}
