import { tags } from "typia";
export declare namespace IApiReposActionsCaches {
    type GetHeader = {
        /**
         * The account owner of the repository. The name is not case sensitive.
         */
        owner: string;
        /**
         * The name of the repository without the `.git` extension. The name is not case sensitive.
         */
        repo: string;
        /**
         * The number of results per page (max 100). For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        per_page?: number & tags.Type<"int32"> & tags.Default<30>;
        /**
         * The page number of the results to fetch. For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        page?: number & tags.Type<"int32"> & tags.Default<1>;
        /**
         * The full Git reference for narrowing down the cache. The `ref` for a branch should be formatted as `refs/heads/<branch name>`. To reference a pull request use `refs/pull/<number>/merge`.
         */
        ref?: string;
        /**
         * An explicit key or prefix for identifying the cache
         */
        key?: string;
    };
    type DeleteHeader = {
        /**
         * The account owner of the repository. The name is not case sensitive.
         */
        owner: string;
        /**
         * The name of the repository without the `.git` extension. The name is not case sensitive.
         */
        repo: string;
        /**
         * The unique identifier of the GitHub Actions cache.
         */
        cache_id: number & tags.Type<"int32">;
    };
}
