import { tags } from "typia";
export declare namespace IApiReposInvitations {
    type GetHeader = {
        /**
         * The account owner of the repository. The name is not case sensitive.
         */
        owner: string;
        /**
         * The name of the repository without the `.git` extension. The name is not case sensitive.
         */
        repo: string;
        /**
         * The number of results per page (max 100). For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        per_page?: number & tags.Type<"int32"> & tags.Default<30>;
        /**
         * The page number of the results to fetch. For more information, see "[Using pagination in the REST API](https://docs.github.com/rest/using-the-rest-api/using-pagination-in-the-rest-api)."
         */
        page?: number & tags.Type<"int32"> & tags.Default<1>;
    };
    type PatchHeader = {
        /**
         * The account owner of the repository. The name is not case sensitive.
         */
        owner: string;
        /**
         * The name of the repository without the `.git` extension. The name is not case sensitive.
         */
        repo: string;
        /**
         * The unique identifier of the invitation.
         */
        invitation_id: number & tags.Type<"int32">;
    };
    type DeleteHeader = {
        /**
         * The account owner of the repository. The name is not case sensitive.
         */
        owner: string;
        /**
         * The name of the repository without the `.git` extension. The name is not case sensitive.
         */
        repo: string;
        /**
         * The unique identifier of the invitation.
         */
        invitation_id: number & tags.Type<"int32">;
    };
}
