import { IConnection } from "@nestia/fetcher";
import typia from "typia";
import { IApiReposVulnerabilityAlerts } from "../../../structures/IApiReposVulnerabilityAlerts";
/**
 * Check if vulnerability alerts are enabled for a repository.
 * Shows whether dependency alerts are enabled or disabled for a repository. The authenticated user must have admin read access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
 *
 * @tag repos
 * @path repos/:owner/:repo/vulnerability-alerts
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function getByOwnerAndRepo(connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace getByOwnerAndRepo {
    type Headers = IApiReposVulnerabilityAlerts.GetHeader;
    const METADATA: {
        readonly method: "GET";
        readonly path: "/repos/:owner/:repo/vulnerability-alerts";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<getByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
/**
 * Enable vulnerability alerts.
 * Enables dependency alerts and the dependency graph for a repository. The authenticated user must have admin access to the repository. For more information, see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
 *
 * @tag repos
 * @path repos/:owner/:repo/vulnerability-alerts
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function putByOwnerAndRepo(connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace putByOwnerAndRepo {
    type Headers = IApiReposVulnerabilityAlerts.PutHeader;
    const METADATA: {
        readonly method: "PUT";
        readonly path: "/repos/:owner/:repo/vulnerability-alerts";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<putByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
/**
 * Disable vulnerability alerts.
 * Disables dependency alerts and the dependency graph for a repository.
 * The authenticated user must have admin access to the repository. For more information,
 * see "[About security alerts for vulnerable dependencies](https://docs.github.com/articles/about-security-alerts-for-vulnerable-dependencies)".
 *
 * @tag repos
 * @path repos/:owner/:repo/vulnerability-alerts
 * @nestia Generated by Nestia - https://github.com/samchon/nestia
 */
export declare function eraseByOwnerAndRepo(connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string): Promise<void>;
export declare namespace eraseByOwnerAndRepo {
    type Headers = IApiReposVulnerabilityAlerts.DeleteHeader;
    const METADATA: {
        readonly method: "DELETE";
        readonly path: "/repos/:owner/:repo/vulnerability-alerts";
        readonly request: null;
        readonly response: {
            readonly type: "application/json";
            readonly encrypted: false;
        };
    };
    const path: (owner: string, repo: string) => string;
    const random: (g?: Partial<typia.IRandomGenerator>) => void;
    const simulate: (connection: IConnection<eraseByOwnerAndRepo.Headers>, owner: string, repo: string) => void;
}
